-- suite8.11.0.sp8.1-Scripts-Oracle.sql last modified on 02/11/2018

-- Instructions - Use search and replace to replace the following.
--   1) Replace <INDEX_TABLESPACE> with the tablespace name that will be used to store indexes.
--   2) Replace <LOGIN> with the login the application will use to access the database.


---------------- Begin Checks For Auditing Section  ----------------

-- Gather auditing information

BEGIN
  EXECUTE IMMEDIATE 'drop table tmp_AuditingUpgrade';
  EXCEPTION
    WHEN OTHERS THEN null;
END;
/

create table tmp_AuditingUpgrade
(
    TableName                            VARCHAR2(50)    null,
    UpgradeTable                         CHAR(1)        null,
    UpgradeTrigger                       CHAR(1)        null
)
/


insert into tmp_AuditingUpgrade values ('Invoice','F','F');
insert into tmp_AuditingUpgrade values ('Company','F','F');
insert into tmp_AuditingUpgrade values ('Matter','F','F');
insert into tmp_AuditingUpgrade values ('Person','F','F');

commit;


DECLARE
  v_ObjectCount         NUMBER(1);
BEGIN
  SELECT COUNT(*)
    INTO v_ObjectCount
    FROM User_Tables
    WHERE Table_Name = 'INVOICE_AUDIT';

  IF v_ObjectCount = 1 THEN
    UPDATE tmp_AuditingUpgrade
      SET UpgradeTable = 'T'
      WHERE TableName = 'Invoice';
      COMMIT;
    ELSE
      NULL;
  END IF;
END;
/

DECLARE
  v_ObjectCount         NUMBER(1);
BEGIN
  SELECT COUNT(*)
    INTO v_ObjectCount
    FROM User_Triggers
    WHERE Trigger_Name = 'AUDIT_INVOICE';

  IF v_ObjectCount = 1 THEN
    UPDATE tmp_AuditingUpgrade
      SET UpgradeTrigger = 'T'
      WHERE TableName = 'Invoice';
      COMMIT;
	  EXECUTE IMMEDIATE 'drop trigger AUDIT_INVOICE';
  ELSE
      NULL;
  END IF;
END;
/

/*Company*/
DECLARE
  v_ObjectCount         NUMBER(1);
BEGIN
  SELECT COUNT(*)
    INTO v_ObjectCount
    FROM User_Tables
    WHERE Table_Name = 'COMPANY_AUDIT';

  IF v_ObjectCount = 1 THEN
    UPDATE tmp_AuditingUpgrade
      SET UpgradeTable = 'T'
      WHERE TableName = 'Company';
      COMMIT;
    ELSE
      NULL;
  END IF;
END;
/

DECLARE
  v_ObjectCount         NUMBER(1);
BEGIN
  SELECT COUNT(*)
    INTO v_ObjectCount
    FROM User_Triggers
    WHERE Trigger_Name = 'AUDIT_COMPANY';

  IF v_ObjectCount = 1 THEN
    UPDATE tmp_AuditingUpgrade
      SET UpgradeTrigger = 'T'
      WHERE TableName = 'Company';
      COMMIT;
	  EXECUTE IMMEDIATE 'drop trigger AUDIT_COMPANY';
    ELSE
      NULL;
  END IF;
END;
/

/*Matter*/
DECLARE
  v_ObjectCount         NUMBER(1);
BEGIN
  SELECT COUNT(*)
    INTO v_ObjectCount
    FROM User_Tables
    WHERE Table_Name = 'MATTER_AUDIT';

  IF v_ObjectCount = 1 THEN
    UPDATE tmp_AuditingUpgrade
      SET UpgradeTable = 'T'
      WHERE TableName = 'Matter';
      COMMIT;
    ELSE
      NULL;
  END IF;
END;
/

DECLARE
  v_ObjectCount         NUMBER(1);
BEGIN
  SELECT COUNT(*)
    INTO v_ObjectCount
    FROM User_Triggers
    WHERE Trigger_Name = 'AUDIT_MATTER';

  IF v_ObjectCount = 1 THEN
    UPDATE tmp_AuditingUpgrade
      SET UpgradeTrigger = 'T'
      WHERE TableName = 'Matter';
      COMMIT;
	  EXECUTE IMMEDIATE 'drop trigger AUDIT_MATTER';
    ELSE
      NULL;
  END IF;
END;
/

/*Person*/
DECLARE
  v_ObjectCount         NUMBER(1);
BEGIN
  SELECT COUNT(*)
    INTO v_ObjectCount
    FROM User_Tables
    WHERE Table_Name = 'PERSON_AUDIT';

  IF v_ObjectCount = 1 THEN
    UPDATE tmp_AuditingUpgrade
      SET UpgradeTable = 'T'
      WHERE TableName = 'Person';
      COMMIT;
    ELSE
      NULL;
  END IF;
END;
/

DECLARE
  v_ObjectCount         NUMBER(1);
BEGIN
  SELECT COUNT(*)
    INTO v_ObjectCount
    FROM User_Triggers
    WHERE Trigger_Name = 'AUDIT_PERSON';

  IF v_ObjectCount = 1 THEN
    UPDATE tmp_AuditingUpgrade
      SET UpgradeTrigger = 'T'
      WHERE TableName = 'Person';
      COMMIT;
	  EXECUTE IMMEDIATE 'drop trigger AUDIT_PERSON';
    ELSE
      NULL;
  END IF;
END;
/

---------------- End Checks For Auditing Section  ----------------

---------------- Begin Structural Section ----------------

/*Company*/
--Disable constraints 
alter table AlternateName
    DROP CONSTRAINT FK_ALTERNAT_REF_1426_COMPANY;
/

alter table CALURA
    DROP CONSTRAINT FK_CALURA_REF_1180_COMPANY;
/

alter table Canada
    DROP CONSTRAINT FK_CANADA_REF_1174_COMPANY;
/

alter table Chart
    DROP CONSTRAINT FK_CHART_REF_1519_COMPANY;
/

alter table Company_Person
    DROP CONSTRAINT FK_COMPANY__REF_1267_COMPANY;
/

alter table DBAName	
    DROP CONSTRAINT FK_DBANAME_REF_1172_COMPANY;
/

alter table FormerName
    DROP CONSTRAINT FK_FORMERNA_REF_1173_COMPANY;
/

alter table InsurancePolicy
    DROP CONSTRAINT FK_INSURANC_REF_1270_COMPANY;
/

alter table Member
    DROP CONSTRAINT FK_MEMBER_REF_1186_COMPANY;
/

alter table Ownership
    DROP CONSTRAINT FK_OWNERSHI_REF_1178_COMPANY;
/

alter table Registration
    DROP CONSTRAINT FK_REGISTRA_REF_1183_COMPANY;
/

alter table Security
    DROP CONSTRAINT FK_SECURITY_REF_1170_COMPANY;
/

--Create tmp_Company
BEGIN
  EXECUTE IMMEDIATE 'drop table tmp_Company';
  EXCEPTION
    WHEN OTHERS THEN null;
END;
/

create table tmp_Company(
Company_ID         NUMBER(10,0)                    not null,
   AlternateName      VARCHAR2(150),
   AdministrationNumber VARCHAR2(20),
   InternalNumber     VARCHAR2(40),
   FiscalYearEnd      VARCHAR2(40),
   TaxYearEnd         VARCHAR2(40),
   HasEmployees       CHAR(1)                        default 'F',
   Purpose_ID         NUMBER(10,0),
   AgreementDate      DATE,
   TerminationDate    DATE,
   AnnualMeetingMonth NUMBER(10,0),
   AnnualMeetingNotes_ID NUMBER(10,0),
   AnnualMeetingDate  DATE,
   DirectorsMin       NUMBER(10,0),
   DirectorsMax       NUMBER(10,0),
   DirectorsAuthorized NUMBER(10,0),
   DirectorsQuorum    VARCHAR2(255),
   BoardClasses       NUMBER(10,0),
   BooksLocation      VARCHAR2(255),
   SealLocation       VARCHAR2(255),
   Successor_EID      NUMBER(10,0),
   Comments_ID        NUMBER(10,0),
   DirectorsComments_ID NUMBER(10,0),
   LastMeetingDate    DATE,
   CorpStatusDate     DATE,
   LLCGovernedBy      NUMBER(10,0),
   CompanyType_CD     VARCHAR2(40),
   AccountCode        VARCHAR2(40),
   ChargeBackPct      NUMBER(10,4),
   ChargeBackBeginDate DATE,
   ChargeBackCode1    VARCHAR2(100),
   ChargeBackCode2    VARCHAR2(100),
   ChargeBackCode3    VARCHAR2(100),
   LineOfBusiness_CD  VARCHAR2(40),
   IsInsuranceCompany CHAR(1)                        default 'F',
   IsBillingEntity    CHAR(1)                        default 'F',
   ExternalEntityNumber VARCHAR2(20),
   eInvoicingVendorID VARCHAR2(50),
   LHOrganizationID	  VARCHAR2(50),
   ApprovedFirm       CHAR(1)                        default 'F',
   ApprovedDate       DATE,
   DismissalDate      DATE,
   BillsCustomer      CHAR(1)                        default 'F',
   BillingMethod_CD   VARCHAR2(40),
   PaymentMethod_CD   VARCHAR2(40),
   GuidelinesReturned CHAR(1)                        default 'F',
   DateGuidelinesReturned DATE,
   FemaleOwnership    CHAR(1)                        default 'F',
   MinorityFirm       CHAR(1)                        default 'F',
   Domicile_CD        VARCHAR2(40),
   Region_CD          VARCHAR2(40),
   SubType_CD         VARCHAR2(40),
   Reject             CHAR(1)                        default 'F',
   BeginDate          DATE,
   EndDate            DATE,
   ChangeBy           VARCHAR2(20),
   LastChange         DATE,
   CompanyType_CAT    NUMBER(10,0),
   LineOfBusiness_CAT NUMBER(10,0),
   BillingMethod_CAT  NUMBER(10,0),
   PaymentMethod_CAT  NUMBER(10,0),
   Domicile_CAT       NUMBER(10,0),
   Region_CAT         NUMBER(10,0),
   SubType_CAT        NUMBER(10,0)
);
/

insert into tmp_Company
(
Company_ID,
   AlternateName,
   AdministrationNumber,
   InternalNumber,
   FiscalYearEnd,
   TaxYearEnd,
   HasEmployees,
   Purpose_ID,
   AgreementDate,
   TerminationDate,
   AnnualMeetingMonth,
   AnnualMeetingNotes_ID,
   AnnualMeetingDate,
   DirectorsMin,
   DirectorsMax,
   DirectorsAuthorized,
   DirectorsQuorum,
   BoardClasses,
   BooksLocation,
   SealLocation,
   Successor_EID,
   Comments_ID,
   DirectorsComments_ID,
   LastMeetingDate,
   CorpStatusDate,
   LLCGovernedBy,
   CompanyType_CD,
   AccountCode,
   ChargeBackPct,
   ChargeBackBeginDate,
   ChargeBackCode1,
   ChargeBackCode2,
   ChargeBackCode3,
   LineOfBusiness_CD,
   IsInsuranceCompany,
   IsBillingEntity,
   ExternalEntityNumber,
   eInvoicingVendorID,
   ApprovedFirm,
   ApprovedDate,
   DismissalDate,
   BillsCustomer,
   BillingMethod_CD,
   PaymentMethod_CD,
   GuidelinesReturned,
   DateGuidelinesReturned,
   FemaleOwnership,
   MinorityFirm,
   Domicile_CD,
   Region_CD,
   SubType_CD,
   Reject,
   BeginDate,
   EndDate,
   ChangeBy,
   LastChange,
   CompanyType_CAT,
   LineOfBusiness_CAT,
   BillingMethod_CAT,
   PaymentMethod_CAT,
   Domicile_CAT,
   Region_CAT,
   SubType_CAT
)
select 
Company_ID,
   AlternateName,
   AdministrationNumber,
   InternalNumber,
   FiscalYearEnd,
   TaxYearEnd,
   HasEmployees,
   Purpose_ID,
   AgreementDate,
   TerminationDate,
   AnnualMeetingMonth,
   AnnualMeetingNotes_ID,
   AnnualMeetingDate,
   DirectorsMin,
   DirectorsMax,
   DirectorsAuthorized,
   DirectorsQuorum,
   BoardClasses,
   BooksLocation,
   SealLocation,
   Successor_EID,
   Comments_ID,
   DirectorsComments_ID,
   LastMeetingDate,
   CorpStatusDate,
   LLCGovernedBy,
   CompanyType_CD,
   AccountCode,
   ChargeBackPct,
   ChargeBackBeginDate,
   ChargeBackCode1,
   ChargeBackCode2,
   ChargeBackCode3,
   LineOfBusiness_CD,
   IsInsuranceCompany,
   IsBillingEntity,
   ExternalEntityNumber,
   eInvoicingVendorID,
   ApprovedFirm,
   ApprovedDate,
   DismissalDate,
   BillsCustomer,
   BillingMethod_CD,
   PaymentMethod_CD,
   GuidelinesReturned,
   DateGuidelinesReturned,
   FemaleOwnership,
   MinorityFirm,
   Domicile_CD,
   Region_CD,
   SubType_CD,
   Reject,
   BeginDate,
   EndDate,
   ChangeBy,
   LastChange,
   CompanyType_CAT,
   LineOfBusiness_CAT,
   BillingMethod_CAT,
   PaymentMethod_CAT,
   Domicile_CAT,
   Region_CAT,
   SubType_CAT from COMPANY;
   /
   commit;
   /
 drop table Company;
   /
   
   create table Company  (
   Company_ID         NUMBER(10,0)                    not null,
   AlternateName      VARCHAR2(150),
   AdministrationNumber VARCHAR2(20),
   InternalNumber     VARCHAR2(40),
   FiscalYearEnd      VARCHAR2(40),
   TaxYearEnd         VARCHAR2(40),
   HasEmployees       CHAR(1)                        default 'F',
   Purpose_ID         NUMBER(10,0),
   AgreementDate      DATE,
   TerminationDate    DATE,
   AnnualMeetingMonth NUMBER(10,0),
   AnnualMeetingNotes_ID NUMBER(10,0),
   AnnualMeetingDate  DATE,
   DirectorsMin       NUMBER(10,0),
   DirectorsMax       NUMBER(10,0),
   DirectorsAuthorized NUMBER(10,0),
   DirectorsQuorum    VARCHAR2(255),
   BoardClasses       NUMBER(10,0),
   BooksLocation      VARCHAR2(255),
   SealLocation       VARCHAR2(255),
   Successor_EID      NUMBER(10,0),
   Comments_ID        NUMBER(10,0),
   DirectorsComments_ID NUMBER(10,0),
   LastMeetingDate    DATE,
   CorpStatusDate     DATE,
   LLCGovernedBy      NUMBER(10,0),
   CompanyType_CD     VARCHAR2(40),
   AccountCode        VARCHAR2(40),
   ChargeBackPct      NUMBER(10,4),
   ChargeBackBeginDate DATE,
   ChargeBackCode1    VARCHAR2(100),
   ChargeBackCode2    VARCHAR2(100),
   ChargeBackCode3    VARCHAR2(100),
   LineOfBusiness_CD  VARCHAR2(40),
   IsInsuranceCompany CHAR(1)                        default 'F',
   IsBillingEntity    CHAR(1)                        default 'F',
   ExternalEntityNumber VARCHAR2(20),
   eInvoicingVendorID VARCHAR2(50),
   LHOrganizationID	  VARCHAR2(50),
   ApprovedFirm       CHAR(1)                        default 'F',
   ApprovedDate       DATE,
   DismissalDate      DATE,
   BillsCustomer      CHAR(1)                        default 'F',
   BillingMethod_CD   VARCHAR2(40),
   PaymentMethod_CD   VARCHAR2(40),
   GuidelinesReturned CHAR(1)                        default 'F',
   DateGuidelinesReturned DATE,
   FemaleOwnership    CHAR(1)                        default 'F',
   MinorityFirm       CHAR(1)                        default 'F',
   Domicile_CD        VARCHAR2(40),
   Region_CD          VARCHAR2(40),
   SubType_CD         VARCHAR2(40),
   Reject             CHAR(1)                        default 'F',
   BeginDate          DATE,
   EndDate            DATE,
   ChangeBy           VARCHAR2(20),
   LastChange         DATE,
   CompanyType_CAT    NUMBER(10,0),
   LineOfBusiness_CAT NUMBER(10,0),
   BillingMethod_CAT  NUMBER(10,0),
   PaymentMethod_CAT  NUMBER(10,0),
   Domicile_CAT       NUMBER(10,0),
   Region_CAT         NUMBER(10,0),
   SubType_CAT        NUMBER(10,0),
   constraint PK_COMPANY primary key (Company_ID)
         using index tablespace <INDEX_TABLESPACE>
);

create index IDX_COMP_SUCCESSOR_EID on Company (
   Successor_EID ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_COMP_PURPOSE_ID on Company (
   Purpose_ID ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_COMP_COMMENTS_ID on Company (
   Comments_ID ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_COMP_DIRECTORSCOMMENTS_ID on Company (
   DirectorsComments_ID ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_COMP_ANNUALMEETINGNOTES_ID on Company (
   AnnualMeetingNotes_ID ASC
)
tablespace <INDEX_TABLESPACE>;

insert into Company
select * from tmp_Company;
/
--Reenable Constraint 

alter table AlternateName
   add constraint FK_ALTERNAT_REF_1426_COMPANY foreign key (Company_ID)
      references Company (Company_ID);
/

alter table CALURA
   add constraint FK_CALURA_REF_1180_COMPANY foreign key (Company_ID)
      references Company (Company_ID);
/

alter table Canada
   add constraint FK_CANADA_REF_1174_COMPANY foreign key (Company_ID)
      references Company (Company_ID);
/

alter table Chart
   add constraint FK_CHART_REF_1519_COMPANY foreign key (Company_ID)
      references Company (Company_ID);
/

alter table Company_Person
   add constraint FK_COMPANY__REF_1267_COMPANY foreign key (Company_ID)
      references Company (Company_ID);
/

alter table DBAName
   add constraint FK_DBANAME_REF_1172_COMPANY foreign key (Company_ID)
      references Company (Company_ID);
/

alter table FormerName
   add constraint FK_FORMERNA_REF_1173_COMPANY foreign key (Company_ID)
      references Company (Company_ID);
/

alter table InsurancePolicy
   add constraint FK_INSURANC_REF_1270_COMPANY foreign key (InsuranceCompany_ID)
      references Company (Company_ID);
/

alter table Member
   add constraint FK_MEMBER_REF_1186_COMPANY foreign key (Company_ID)
      references Company (Company_ID);
/

alter table Ownership
   add constraint FK_OWNERSHI_REF_1178_COMPANY foreign key (Company_ID)
      references Company (Company_ID);
/

alter table Registration
   add constraint FK_REGISTRA_REF_1183_COMPANY foreign key (Company_ID)
      references Company (Company_ID);
/

alter table Security
   add constraint FK_SECURITY_REF_1170_COMPANY foreign key (Company_ID)
      references Company (Company_ID);
/
alter table Company
   add constraint FK_COMPANY_REF_1006_ENTITY foreign key (Successor_EID)
      references Entity (Entity_EID);
/
alter table Company
   add constraint FK_COMPANY_REF_1018_LONGCOMM foreign key (Purpose_ID)
      references LongComments (Comments_ID);
/
alter table Company
   add constraint FK_COMPANY_REF_1221_LONGCOMM foreign key (Comments_ID)
      references LongComments (Comments_ID);
/
alter table Company
   add constraint FK_COMPANY_REF_1222_LONGCOMM foreign key (DirectorsComments_ID)
      references LongComments (Comments_ID);
/
alter table Company
   add constraint FK_COMPANY_REF_1269_ENTITY foreign key (Company_ID)
      references Entity (Entity_EID);
/
alter table Company
   add constraint FK_COMPANY_REF_1429_LONGCOMM foreign key (AnnualMeetingNotes_ID)
      references LongComments (Comments_ID);
/

drop table tmp_Company;
/	

/*Matter*/
--Disable constraints 
alter table CalendarEvent
    DROP CONSTRAINT FK_CALENDAR_REF_1155_MATTER;
/

alter table Document
    DROP CONSTRAINT FK_DOCUMENT_REF_1116_MATTER;
/

alter table DocumentFile
    DROP CONSTRAINT FK_DOCUMENT_REF_1431_MATTER;
/

alter table Evaluation
    DROP CONSTRAINT FK_EVALUATI_REF_1080_MATTER;
/

alter table Evaluation
    DROP CONSTRAINT FK_EVALUATI_REF_3139_MATTER;
/

alter table MatterAccrual
    DROP CONSTRAINT FK_MATTERAC_REF_3131_MATTER;
/

alter table MatterBudget
    DROP CONSTRAINT FK_MATTERBU_REF_1126_MATTER;
/

alter table MatterDamage
    DROP CONSTRAINT FK_MATTERDA_REF_1349_MATTER;
/

alter table MatterExposure
    DROP CONSTRAINT FK_MATTEREX_REF_1135_MATTER;
/

alter table MatterInsurancePolicy
    DROP CONSTRAINT FK_MATTERIN_REF_1131_MATTER;
/

alter table MatterInvoice
    DROP CONSTRAINT FK_MATTERIN_REF_1311_MATTER;
/

alter table MatterLitigation
    DROP CONSTRAINT FK_MATTERLI_REF_1129_MATTER;
/

alter table MatterNegotiation
    DROP CONSTRAINT FK_MATTERNE_REF_1128_MATTER;
/

alter table MatterPlayer
    DROP CONSTRAINT FK_MATTERPL_REF_1127_MATTER;
/

alter table MatterRecovery
    DROP CONSTRAINT FK_MATTERRE_REF_1137_MATTER;
/

alter table MatterRelationship
    DROP CONSTRAINT FK_MATTERRE_REF_1293_MATTER;
/

alter table MatterRelationship
    DROP CONSTRAINT FK_MATTERRE_REF_1312_MATTER;
/

alter table MatterReserve
    DROP CONSTRAINT FK_MATTERRE_REF_1328_MATTER;
/

alter table Patent
    DROP CONSTRAINT FK_PATENT_REF_1160_MATTER;
/

alter table PhysicalFile
    DROP CONSTRAINT FK_PHYSICAL_REF_1493_MATTER;
/

alter table Trademark
    DROP CONSTRAINT FK_TRADEMAR_REF_1159_MATTER;
/

alter table User_Matter
    DROP CONSTRAINT FK_USER_MAT_REF_1528_MATTER;
/

alter table UserField
    DROP CONSTRAINT FK_USERFIEL_REF_3120_MATTER;
/


BEGIN
  EXECUTE IMMEDIATE 'drop table tmp_Matter';
  EXCEPTION
    WHEN OTHERS THEN null;
END;
/

create table tmp_Matter(
MatterNumber_ID    NUMBER(10,0)                    not null,
   Matter_CD          VARCHAR2(40)                    not null,
   MatterStatus_CD    VARCHAR2(40),
   LogicalGroup_ID    NUMBER(10,0),
   MatterNumber       VARCHAR2(40)                    not null,
   MatterName         VARCHAR2(200)                   not null,
   FileNumber         VARCHAR2(20),
   ProductService_CD  VARCHAR2(40),
   SubProductService_CD VARCHAR2(40),
   OpenDate           DATE                            not null,
   OpenDate_ID        NUMBER(10,0),
   CloseDate          DATE,
   CloseDate_ID       NUMBER(10,0),
   ReOpenDate         DATE,
   ReOpenDate_ID      NUMBER(10,0),
   Law_CD             VARCHAR2(40),
   SubLaw_CD          VARCHAR2(40),
   LongMatterName_ID  NUMBER(10,0),
   LongMatterName     VARCHAR2(4000),
   Comments_ID        NUMBER(10,0),
   TargetDate         DATE,
   TargetDate_ID      NUMBER(10,0),
   State_CD           VARCHAR2(40),
   Country_CD         VARCHAR2(40),
   Region_CD          VARCHAR2(40),
   Litigated          CHAR(1)                        default 'F' not null,
   LegalSection_CD    VARCHAR2(40)                    not null,
   Budgeted           CHAR(1)                        default 'F' not null,
   Insured            CHAR(1)                        default 'F' not null,
   AccrueCosts        CHAR(1)                        default 'F' not null,
   Priority_CD        VARCHAR2(40),
   PrivateMatter      CHAR(1)                        default 'F',
   PrivateChangeBy_ID NUMBER(10,0),
   PrivateChangeDate  DATE,
   Exported           CHAR(1)                        default 'F',
   BillAfterClose     CHAR(1)                        default 'T',
   eInvoicingMatterID VARCHAR2(50),
   NeedSync      	  CHAR(1)                        default 'F',
   CollaboratiSync    CHAR(1)                        default 'F',
   LHMatterID		  VARCHAR2(50),
   ActiveHolds		  NUMBER(10,0),
   CreatedDate        DATE,
   ChangeBy           VARCHAR2(20),
   LastChange         DATE,
   Matter_CAT         NUMBER(10,0)                    not null,
   MatterStatus_CAT   NUMBER(10,0),
   ProductService_CAT NUMBER(10,0),
   SubProductService_CAT NUMBER(10,0),
   Law_CAT            NUMBER(10,0),
   SubLaw_CAT         NUMBER(10,0),
   State_CAT          NUMBER(10,0),
   Country_CAT        NUMBER(10,0),
   Region_CAT         NUMBER(10,0),
   LegalSection_CAT   NUMBER(10,0)                    not null,
   Priority_CAT       NUMBER(10,0)
);
/

insert into tmp_Matter
(
MatterNumber_ID,
   Matter_CD,
   MatterStatus_CD,
   LogicalGroup_ID,
   MatterNumber,
   MatterName,
   FileNumber,
   ProductService_CD,
   SubProductService_CD,
   OpenDate,
   OpenDate_ID,
   CloseDate,
   CloseDate_ID,
   ReOpenDate,
   ReOpenDate_ID,
   Law_CD,
   SubLaw_CD,
   LongMatterName_ID,
   LongMatterName,
   Comments_ID,
   TargetDate,
   TargetDate_ID,
   State_CD,
   Country_CD,
   Region_CD,
   Litigated,
   LegalSection_CD,
   Budgeted,
   Insured,
   AccrueCosts,
   Priority_CD,
   PrivateMatter,
   PrivateChangeBy_ID,
   PrivateChangeDate,
   Exported,
   BillAfterClose,
   eInvoicingMatterID,
   NeedSync,
   CollaboratiSync,
   CreatedDate,
   ChangeBy,
   LastChange,
   Matter_CAT,
   MatterStatus_CAT,
   ProductService_CAT,
   SubProductService_CAT,
   Law_CAT,
   SubLaw_CAT,
   State_CAT,
   Country_CAT,
   Region_CAT,
   LegalSection_CAT,
   Priority_CAT
   )
   select 
   MatterNumber_ID,
   Matter_CD,
   MatterStatus_CD,
   LogicalGroup_ID,
   MatterNumber,
   MatterName,
   FileNumber,
   ProductService_CD,
   SubProductService_CD,
   OpenDate,
   OpenDate_ID,
   CloseDate,
   CloseDate_ID,
   ReOpenDate,
   ReOpenDate_ID,
   Law_CD,
   SubLaw_CD,
   LongMatterName_ID,
   LongMatterName,
   Comments_ID,
   TargetDate,
   TargetDate_ID,
   State_CD,
   Country_CD,
   Region_CD,
   Litigated,
   LegalSection_CD,
   Budgeted,
   Insured,
   AccrueCosts,
   Priority_CD,
   PrivateMatter,
   PrivateChangeBy_ID,
   PrivateChangeDate,
   Exported,
   BillAfterClose,
   eInvoicingMatterID,
   NeedSync,
   CollaboratiSync,
   CreatedDate,
   ChangeBy,
   LastChange,
   Matter_CAT,
   MatterStatus_CAT,
   ProductService_CAT,
   SubProductService_CAT,
   Law_CAT,
   SubLaw_CAT,
   State_CAT,
   Country_CAT,
   Region_CAT,
   LegalSection_CAT,
   Priority_CAT from Matter;
   /
   
   commit;
   /
   
 drop table Matter;
   /
   
   create table Matter  (
   MatterNumber_ID    NUMBER(10,0)                    not null,
   Matter_CD          VARCHAR2(40)                    not null,
   MatterStatus_CD    VARCHAR2(40),
   LogicalGroup_ID    NUMBER(10,0),
   MatterNumber       VARCHAR2(40)                    not null,
   MatterName         VARCHAR2(200)                   not null,
   FileNumber         VARCHAR2(20),
   ProductService_CD  VARCHAR2(40),
   SubProductService_CD VARCHAR2(40),
   OpenDate           DATE                            not null,
   OpenDate_ID        NUMBER(10,0),
   CloseDate          DATE,
   CloseDate_ID       NUMBER(10,0),
   ReOpenDate         DATE,
   ReOpenDate_ID      NUMBER(10,0),
   Law_CD             VARCHAR2(40),
   SubLaw_CD          VARCHAR2(40),
   LongMatterName_ID  NUMBER(10,0),
   LongMatterName     VARCHAR2(4000),
   Comments_ID        NUMBER(10,0),
   TargetDate         DATE,
   TargetDate_ID      NUMBER(10,0),
   State_CD           VARCHAR2(40),
   Country_CD         VARCHAR2(40),
   Region_CD          VARCHAR2(40),
   Litigated          CHAR(1)                        default 'F' not null,
   LegalSection_CD    VARCHAR2(40)                    not null,
   Budgeted           CHAR(1)                        default 'F' not null,
   Insured            CHAR(1)                        default 'F' not null,
   AccrueCosts        CHAR(1)                        default 'F' not null,
   Priority_CD        VARCHAR2(40),
   PrivateMatter      CHAR(1)                        default 'F',
   PrivateChangeBy_ID NUMBER(10,0),
   PrivateChangeDate  DATE,
   Exported           CHAR(1)                        default 'F',
   BillAfterClose     CHAR(1)                        default 'T',
   eInvoicingMatterID VARCHAR2(50),
   NeedSync      	  CHAR(1)                        default 'F',
   CollaboratiSync    CHAR(1)                        default 'F',
   LHMatterID		  VARCHAR2(50),
   ActiveHolds		  NUMBER(10,0),
   CreatedDate        DATE,
   ChangeBy           VARCHAR2(20),
   LastChange         DATE,
   Matter_CAT         NUMBER(10,0)                    not null,
   MatterStatus_CAT   NUMBER(10,0),
   ProductService_CAT NUMBER(10,0),
   SubProductService_CAT NUMBER(10,0),
   Law_CAT            NUMBER(10,0),
   SubLaw_CAT         NUMBER(10,0),
   State_CAT          NUMBER(10,0),
   Country_CAT        NUMBER(10,0),
   Region_CAT         NUMBER(10,0),
   LegalSection_CAT   NUMBER(10,0)                    not null,
   Priority_CAT       NUMBER(10,0),
   constraint PK_MATTER primary key (MatterNumber_ID)
         using index tablespace <INDEX_TABLESPACE>
);

create index IDX_MATT_MATTERNUMBER on Matter (
   MatterNumber ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_MATT_MATTERNAME on Matter (
   MatterName ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_MATT_LOGICALGROUP_ID on Matter (
   LogicalGroup_ID ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_MATT_COMMENTS_ID on Matter (
   Comments_ID ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_MATT_LONGMATTERNAME_ID on Matter (
   LongMatterName_ID ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_MATT_PRIVATECHANGEBY_ID on Matter (
   PrivateChangeBy_ID ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_MATT_PRIVATEMATTER on Matter (
   PrivateMatter ASC
)
tablespace <INDEX_TABLESPACE>;

insert into Matter 
select * from tmp_Matter;
/

--Reenable constraint
alter table CalendarEvent
   add constraint FK_CALENDAR_REF_1155_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/
alter table Document
   add constraint FK_DOCUMENT_REF_1116_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table DocumentFile
   add constraint FK_DOCUMENT_REF_1431_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table Evaluation
   add constraint FK_EVALUATI_REF_1080_MATTER foreign key (RelatedMatter_ID)
      references Matter (MatterNumber_ID);
/	  
   
 alter table Evaluation
   add constraint FK_EVALUATI_REF_3139_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterAccrual
   add constraint FK_MATTERAC_REF_3131_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterBudget
   add constraint FK_MATTERBU_REF_1126_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterDamage
   add constraint FK_MATTERDA_REF_1349_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterExposure
   add constraint FK_MATTEREX_REF_1135_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterInsurancePolicy
   add constraint FK_MATTERIN_REF_1131_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterInvoice
   add constraint FK_MATTERIN_REF_1311_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterLitigation
   add constraint FK_MATTERLI_REF_1129_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterNegotiation
   add constraint FK_MATTERNE_REF_1128_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterPlayer
   add constraint FK_MATTERPL_REF_1127_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterRecovery
   add constraint FK_MATTERRE_REF_1137_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterRelationship
   add constraint FK_MATTERRE_REF_1293_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterRelationship
   add constraint FK_MATTERRE_REF_1312_MATTER foreign key (RelatedMatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table MatterReserve
   add constraint FK_MATTERRE_REF_1328_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table Patent
   add constraint FK_PATENT_REF_1160_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table PhysicalFile
   add constraint FK_PHYSICAL_REF_1493_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table Trademark
   add constraint FK_TRADEMAR_REF_1159_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table UserField
   add constraint FK_USERFIEL_REF_3120_MATTER foreign key (MatterField_ID)
      references Matter (MatterNumber_ID);
/

alter table User_Matter
   add constraint FK_USER_MAT_REF_1528_MATTER foreign key (MatterNumber_ID)
      references Matter (MatterNumber_ID);
/

alter table Matter
   add constraint FK_MATTER_REF_1196_LOGICALG foreign key (LogicalGroup_ID)
      references LogicalGroup (LogicalGroup_ID);
/

alter table Matter
   add constraint FK_MATTER_REF_1234_LONGCOMM foreign key (Comments_ID)
      references LongComments (Comments_ID);
/

alter table Matter
   add constraint FK_MATTER_REF_1235_LONGCOMM foreign key (LongMatterName_ID)
      references LongComments (Comments_ID);
/

alter table Matter
   add constraint FK_MATTER_REF_1526_USERS foreign key (PrivateChangeBy_ID)
      references Users (User_ID);
/

drop table tmp_Matter;
/	  

--Person 
--Disable Constraint 
 alter table Company_Person
    DROP CONSTRAINT FK_COMPANY__REF_1266_PERSON;
/

alter table Court_Person
    DROP CONSTRAINT FK_COURT_PE_REF_1320_PERSON;
/

BEGIN
  EXECUTE IMMEDIATE 'drop table tmp_Person';
  EXCEPTION
    WHEN OTHERS THEN null;
END;
/

create table tmp_Person (	  
Person_ID          NUMBER(10,0)                    not null,
   LastName           VARCHAR2(30)                    not null,
   FirstName          VARCHAR2(30),
   Middle             VARCHAR2(30),
   Suffix             VARCHAR2(20),
   Salutation         VARCHAR2(15),
   Nickname           VARCHAR2(15),
   Initials           VARCHAR2(8),
   AdministrationNumber VARCHAR2(20),
   Employee           CHAR(1)                        default 'F',
   EmployeeStartDate  DATE,
   EmployeeEndDate    DATE,
   Spouse             VARCHAR2(40),
   SpouseSSN          VARCHAR2(20),
   Gender             CHAR(1),
   EthnicClassification_CD VARCHAR2(40),
   Secretary          VARCHAR2(40),
   BirthDate          DATE,
   BirthPlace         VARCHAR2(100),
   DeathDate          DATE,
   SecurityLevel      NUMBER(10,0),
   CitizenJurisdiction_ID NUMBER(10,0),
   PassportNumber     VARCHAR2(40),
   DriversLicense     VARCHAR2(20),
   DriversLicenseJurisdiction_ID NUMBER(10,0),
   Timekeeper         CHAR(1),
   AssociatedTimekeeperID VARCHAR2(100),
   TimekeeperSync     CHAR(1)                        default 'F',
   eInvoicingTimekeeperID VARCHAR2(50),
   eInvoicingAuthorized CHAR(1)                      default 'F',
   StartOfWeek        VARCHAR2(15),
   DailyMinumumHours  NUMBER(10,4),
   DailyMaximumHours  NUMBER(10,4),
   WeeklyMinimumHours NUMBER(10,4),
   WeeklyMaximumHours NUMBER(10,4),
   TimekeeperComments_ID NUMBER(10,0),
   LHLegalHoldStaffID VARCHAR2(50),
   Comments_ID        NUMBER(10,0),
   ChangeBy           VARCHAR2(20),
   LastChange         DATE,
   EthnicClassification_CAT NUMBER(10,0)
);	  
/

insert into tmp_Person
(
Person_ID,
   LastName,
   FirstName,
   Middle,
   Suffix,
   Salutation,
   Nickname,
   Initials,
   AdministrationNumber,
   EmployeeStartDate,
   EmployeeEndDate,
   Spouse,
   SpouseSSN,
   Gender,
   EthnicClassification_CD,
   Secretary,
   BirthDate,
   BirthPlace,
   DeathDate,
   SecurityLevel,
   CitizenJurisdiction_ID,
   PassportNumber,
   DriversLicense,
   DriversLicenseJurisdiction_ID,
   Timekeeper,
   AssociatedTimekeeperID,
   TimekeeperSync,
   eInvoicingTimekeeperID,
   eInvoicingAuthorized,
   StartOfWeek,
   DailyMinumumHours,
   DailyMaximumHours,
   WeeklyMinimumHours,
   WeeklyMaximumHours,
   TimekeeperComments_ID,
   Comments_ID,
   ChangeBy,
   LastChange,
   EthnicClassification_CAT
)
select 
Person_ID,
   LastName,
   FirstName,
   Middle,
   Suffix,
   Salutation,
   Nickname,
   Initials,
   AdministrationNumber,
   EmployeeStartDate,
   EmployeeEndDate,
   Spouse,
   SpouseSSN,
   Gender,
   EthnicClassification_CD,
   Secretary,
   BirthDate,
   BirthPlace,
   DeathDate,
   SecurityLevel,
   CitizenJurisdiction_ID,
   PassportNumber,
   DriversLicense,
   DriversLicenseJurisdiction_ID,
   Timekeeper,
   AssociatedTimekeeperID,
   TimekeeperSync,
   eInvoicingTimekeeperID,
   eInvoicingAuthorized,
   StartOfWeek,
   DailyMinumumHours,
   DailyMaximumHours,
   WeeklyMinimumHours,
   WeeklyMaximumHours,
   TimekeeperComments_ID,
   Comments_ID,
   ChangeBy,
   LastChange,
   EthnicClassification_CAT from Person;
/
commit;
/
drop table Person;
/

create table Person  (
   Person_ID          NUMBER(10,0)                    not null,
   LastName           VARCHAR2(30)                    not null,
   FirstName          VARCHAR2(30),
   Middle             VARCHAR2(30),
   Suffix             VARCHAR2(20),
   Salutation         VARCHAR2(15),
   Nickname           VARCHAR2(15),
   Initials           VARCHAR2(8),
   AdministrationNumber VARCHAR2(20),
   Employee           CHAR(1)                        default 'F',
   EmployeeStartDate  DATE,
   EmployeeEndDate    DATE,
   Spouse             VARCHAR2(40),
   SpouseSSN          VARCHAR2(20),
   Gender             CHAR(1),
   EthnicClassification_CD VARCHAR2(40),
   Secretary          VARCHAR2(40),
   BirthDate          DATE,
   BirthPlace         VARCHAR2(100),
   DeathDate          DATE,
   SecurityLevel      NUMBER(10,0),
   CitizenJurisdiction_ID NUMBER(10,0),
   PassportNumber     VARCHAR2(40),
   DriversLicense     VARCHAR2(20),
   DriversLicenseJurisdiction_ID NUMBER(10,0),
   Timekeeper         CHAR(1),
   AssociatedTimekeeperID VARCHAR2(100),
   TimekeeperSync     CHAR(1)                        default 'F',
   eInvoicingTimekeeperID VARCHAR2(50),
   eInvoicingAuthorized CHAR(1)                      default 'F',
   StartOfWeek        VARCHAR2(15),
   DailyMinumumHours  NUMBER(10,4),
   DailyMaximumHours  NUMBER(10,4),
   WeeklyMinimumHours NUMBER(10,4),
   WeeklyMaximumHours NUMBER(10,4),
   TimekeeperComments_ID NUMBER(10,0),
   LHLegalHoldStaffID VARCHAR2(50),
   Comments_ID        NUMBER(10,0),
   ChangeBy           VARCHAR2(20),
   LastChange         DATE,
   EthnicClassification_CAT NUMBER(10,0),
   constraint PK_PERSON primary key (Person_ID)
         using index tablespace <INDEX_TABLESPACE>
);

create index IDX_PERS_ADMINISTRATIONNUMBER on Person (
   AdministrationNumber ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_PERS_CITJURISDICTION_ID on Person (
   CitizenJurisdiction_ID ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_PERS_COMMENTS_ID on Person (
   Comments_ID ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_PERS_DRIVLICJUR_ID on Person (
   DriversLicenseJurisdiction_ID ASC
)
tablespace <INDEX_TABLESPACE>;

create index IDX_PERS_TIMEKCOMMENTS_ID on Person (
   TimekeeperComments_ID ASC
)
tablespace <INDEX_TABLESPACE>;

insert into Person
select * from tmp_Person;
/

--Reenable CONSTRAINTS
alter table Company_Person
   add constraint FK_COMPANY__REF_1266_PERSON foreign key (Person_ID)
      references Person (Person_ID);
/

alter table Court_Person
   add constraint FK_COURT_PE_REF_1320_PERSON foreign key (Person_ID)
      references Person (Person_ID);
/

alter table Person
   add constraint FK_PERSON_REF_1025_JURISDIC foreign key (CitizenJurisdiction_ID)
      references Jurisdiction (Jurisdiction_ID);

alter table Person
   add constraint FK_PERSON_REF_1066_ENTITY foreign key (Person_ID)
      references Entity (Entity_EID);
/

alter table Person
   add constraint FK_PERSON_REF_1212_LONGCOMM foreign key (Comments_ID)
      references LongComments (Comments_ID);
/

alter table Person
   add constraint FK_PERSON_REF_1351_JURISDIC foreign key (DriversLicenseJurisdiction_ID)
      references Jurisdiction (Jurisdiction_ID);
/

alter table Person
   add constraint FK_PERSON_REF_1447_LONGCOMM foreign key (TimekeeperComments_ID)
      references LongComments (Comments_ID);
/

drop table tmp_Person;
/


---------------- Begin Auditing Section ----------------
--COMPANY_AUDIT

BEGIN
  EXECUTE IMMEDIATE 'drop table tmp_Company_Audit';
  EXCEPTION
    WHEN OTHERS THEN null;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Company';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
	  '
create table tmp_Company_Audit
(
old_Company_ID                       NUMBER(10,0)   null,
    new_Company_ID                       NUMBER(10,0)   null,
    old_AlternateName                    VARCHAR2(150)  null,
    new_AlternateName                    VARCHAR2(150)  null,
    old_AdministrationNumber             VARCHAR2(20)   null,
    new_AdministrationNumber             VARCHAR2(20)   null,
    old_InternalNumber                   VARCHAR2(40)   null,
    new_InternalNumber                   VARCHAR2(40)   null,
    old_FiscalYearEnd                    VARCHAR2(40)   null,
    new_FiscalYearEnd                    VARCHAR2(40)   null,
    old_TaxYearEnd                       VARCHAR2(40)   null,
    new_TaxYearEnd                       VARCHAR2(40)   null,
    old_HasEmployees                     CHAR(1)        null,
    new_HasEmployees                     CHAR(1)        null,
    old_Purpose_ID                       NUMBER(10,0)   null,
    new_Purpose_ID                       NUMBER(10,0)   null,
    old_AgreementDate                    DATE           null,
    new_AgreementDate                    DATE           null,
    old_TerminationDate                  DATE           null,
    new_TerminationDate                  DATE           null,
    old_AnnualMeetingMonth               NUMBER(10,0)   null,
    new_AnnualMeetingMonth               NUMBER(10,0)   null,
    old_AnnualMeetingNotes_ID            NUMBER(10,0)   null,
    new_AnnualMeetingNotes_ID            NUMBER(10,0)   null,
    old_AnnualMeetingDate                DATE           null,
    new_AnnualMeetingDate                DATE           null,
    old_DirectorsMin                     NUMBER(10,0)   null,
    new_DirectorsMin                     NUMBER(10,0)   null,
    old_DirectorsMax                     NUMBER(10,0)   null,
    new_DirectorsMax                     NUMBER(10,0)   null,
    old_DirectorsAuthorized              NUMBER(10,0)   null,
    new_DirectorsAuthorized              NUMBER(10,0)   null,
    old_DirectorsQuorum                  VARCHAR2(255)  null,
    new_DirectorsQuorum                  VARCHAR2(255)  null,
    old_BoardClasses                     NUMBER(10,0)   null,
    new_BoardClasses                     NUMBER(10,0)   null,
    old_BooksLocation                    VARCHAR2(255)  null,
    new_BooksLocation                    VARCHAR2(255)  null,
    old_SealLocation                     VARCHAR2(255)  null,
    new_SealLocation                     VARCHAR2(255)  null,
    old_Successor_EID                    NUMBER(10,0)   null,
    new_Successor_EID                    NUMBER(10,0)   null,
    old_Comments_ID                      NUMBER(10,0)   null,
    new_Comments_ID                      NUMBER(10,0)   null,
    old_DirectorsComments_ID             NUMBER(10,0)   null,
    new_DirectorsComments_ID             NUMBER(10,0)   null,
    old_LastMeetingDate                  DATE           null,
    new_LastMeetingDate                  DATE           null,
    old_CorpStatusDate                   DATE           null,
    new_CorpStatusDate                   DATE           null,
    old_LLCGovernedBy                    NUMBER(10,0)   null,
    new_LLCGovernedBy                    NUMBER(10,0)   null,
    old_CompanyType_CD                   VARCHAR2(40)   null,
    new_CompanyType_CD                   VARCHAR2(40)   null,
    old_AccountCode                      VARCHAR2(40)   null,
    new_AccountCode                      VARCHAR2(40)   null,
    old_ChargeBackPct                    NUMBER(10,4)   null,
    new_ChargeBackPct                    NUMBER(10,4)   null,
    old_ChargeBackBeginDate              DATE           null,
    new_ChargeBackBeginDate              DATE           null,
    old_ChargeBackCode1                  VARCHAR2(100)   null,
    new_ChargeBackCode1                  VARCHAR2(100)   null,
    old_ChargeBackCode2                  VARCHAR2(100)   null,
    new_ChargeBackCode2                  VARCHAR2(100)   null,
    old_ChargeBackCode3                  VARCHAR2(100)   null,
    new_ChargeBackCode3                  VARCHAR2(100)   null,
    old_LineOfBusiness_CD                VARCHAR2(40)   null,
    new_LineOfBusiness_CD                VARCHAR2(40)   null,
    old_IsInsuranceCompany               CHAR(1)        null,
    new_IsInsuranceCompany               CHAR(1)        null,
    old_IsBillingEntity                  CHAR(1)        null,
    new_IsBillingEntity                  CHAR(1)        null,
    old_ExternalEntityNumber             VARCHAR2(20)   null,
    new_ExternalEntityNumber             VARCHAR2(20)   null,
	old_eInvoicingVendorID               VARCHAR2(50)   null,
    new_eInvoicingVendorID               VARCHAR2(50)   null,
    old_ApprovedFirm                     CHAR(1)        null,
	old_LHOrganizationID				 VARCHAR2(50)	null,
	new_LHOrganizationID				 VARCHAR2(50)	null,
    new_ApprovedFirm                     CHAR(1)        null,
    old_ApprovedDate                     DATE           null,
    new_ApprovedDate                     DATE           null,
    old_DismissalDate                    DATE           null,
    new_DismissalDate                    DATE           null,
    old_BillsCustomer                    CHAR(1)        null,
    new_BillsCustomer                    CHAR(1)        null,
    old_BillingMethod_CD                 VARCHAR2(40)   null,
    new_BillingMethod_CD                 VARCHAR2(40)   null,
    old_PaymentMethod_CD                 VARCHAR2(40)   null,
    new_PaymentMethod_CD                 VARCHAR2(40)   null,
    old_GuidelinesReturned               CHAR(1)        null,
    new_GuidelinesReturned               CHAR(1)        null,
    old_DateGuidelinesReturned           DATE           null,
    new_DateGuidelinesReturned           DATE           null,
    old_FemaleOwnership                  CHAR(1)        null,
    new_FemaleOwnership                  CHAR(1)        null,
    old_MinorityFirm                     CHAR(1)        null,
    new_MinorityFirm                     CHAR(1)        null,
    old_Domicile_CD                      VARCHAR2(40)   null,
    new_Domicile_CD                      VARCHAR2(40)   null,
    old_Region_CD                        VARCHAR2(40)   null,
    new_Region_CD                        VARCHAR2(40)   null,
    old_SubType_CD                       VARCHAR2(40)   null,
    new_SubType_CD                       VARCHAR2(40)   null,
    old_Reject                           CHAR(1)        null,
    new_Reject                           CHAR(1)        null,
    old_BeginDate                        DATE           null,
    new_BeginDate                        DATE           null,
    old_EndDate                          DATE           null,
    new_EndDate                          DATE           null,
    old_ChangeBy                         VARCHAR2(20)   null,
    new_ChangeBy                         VARCHAR2(20)   null,
    old_LastChange                       DATE           null,
    new_LastChange                       DATE           null,
    old_CompanyType_CAT                  NUMBER(10,0)   null,
    new_CompanyType_CAT                  NUMBER(10,0)   null,
    old_LineOfBusiness_CAT               NUMBER(10,0)   null,
    new_LineOfBusiness_CAT               NUMBER(10,0)   null,
    old_BillingMethod_CAT                NUMBER(10,0)   null,
    new_BillingMethod_CAT                NUMBER(10,0)   null,
    old_PaymentMethod_CAT                NUMBER(10,0)   null,
    new_PaymentMethod_CAT                NUMBER(10,0)   null,
    old_Domicile_CAT                     NUMBER(10,0)   null,
    new_Domicile_CAT                     NUMBER(10,0)   null,
    old_Region_CAT                       NUMBER(10,0)   null,
    new_Region_CAT                       NUMBER(10,0)   null,
    old_SubType_CAT                      NUMBER(10,0)   null,
    new_SubType_CAT                      NUMBER(10,0)   null,
    Transaction_ID                       NUMBER(27,0)   null,
    TransactionType                      CHAR(1)        null,
    TransactionUser                      VARCHAR2(20)   null,
    TransactionDate                      DATE           null
)';
END;
  ELSE
    NULL;
  END IF;
END;
/


DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Company';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
	  '
insert into tmp_Company_Audit
(
old_Company_ID,
    new_Company_ID,
    old_AlternateName,
    new_AlternateName,
    old_AdministrationNumber,
    new_AdministrationNumber,
    old_InternalNumber,
    new_InternalNumber,
    old_FiscalYearEnd,
    new_FiscalYearEnd,
    old_TaxYearEnd,
    new_TaxYearEnd,
    old_HasEmployees,
    new_HasEmployees,
    old_Purpose_ID,
    new_Purpose_ID,
    old_AgreementDate,
    new_AgreementDate,
    old_TerminationDate,
    new_TerminationDate,
    old_AnnualMeetingMonth,
    new_AnnualMeetingMonth,
    old_AnnualMeetingNotes_ID,
    new_AnnualMeetingNotes_ID,
    old_AnnualMeetingDate,
    new_AnnualMeetingDate,
    old_DirectorsMin,
    new_DirectorsMin,
    old_DirectorsMax,
    new_DirectorsMax,
    old_DirectorsAuthorized,
    new_DirectorsAuthorized,
    old_DirectorsQuorum,
    new_DirectorsQuorum,
    old_BoardClasses,
    new_BoardClasses,
    old_BooksLocation,
    new_BooksLocation,
    old_SealLocation,
    new_SealLocation,
    old_Successor_EID,
    new_Successor_EID,
    old_Comments_ID,
    new_Comments_ID,
    old_DirectorsComments_ID,
    new_DirectorsComments_ID,
    old_LastMeetingDate,
    new_LastMeetingDate,
    old_CorpStatusDate,
    new_CorpStatusDate,
    old_LLCGovernedBy,
    new_LLCGovernedBy,
    old_CompanyType_CD,
    new_CompanyType_CD,
    old_AccountCode,
    new_AccountCode,
    old_ChargeBackPct,
    new_ChargeBackPct,
    old_ChargeBackBeginDate,
    new_ChargeBackBeginDate,
    old_ChargeBackCode1,
    new_ChargeBackCode1,
    old_ChargeBackCode2,
    new_ChargeBackCode2,
    old_ChargeBackCode3,
    new_ChargeBackCode3,
    old_LineOfBusiness_CD,
    new_LineOfBusiness_CD,
    old_IsInsuranceCompany,
    new_IsInsuranceCompany,
    old_IsBillingEntity,
    new_IsBillingEntity,
    old_ExternalEntityNumber,
    new_ExternalEntityNumber,
	old_eInvoicingVendorID,
    new_eInvoicingVendorID,
    old_ApprovedFirm,
	new_ApprovedFirm,
    old_ApprovedDate,
    new_ApprovedDate,
    old_DismissalDate,
    new_DismissalDate,
    old_BillsCustomer,
    new_BillsCustomer,
    old_BillingMethod_CD,
    new_BillingMethod_CD,
    old_PaymentMethod_CD,
    new_PaymentMethod_CD,
    old_GuidelinesReturned,
    new_GuidelinesReturned,
    old_DateGuidelinesReturned,
    new_DateGuidelinesReturned,
    old_FemaleOwnership,
    new_FemaleOwnership,
    old_MinorityFirm,
    new_MinorityFirm,
    old_Domicile_CD,
    new_Domicile_CD,
    old_Region_CD,
    new_Region_CD,
    old_SubType_CD,
    new_SubType_CD,
    old_Reject,
    new_Reject,
    old_BeginDate,
    new_BeginDate,
    old_EndDate,
    new_EndDate,
    old_ChangeBy,
    new_ChangeBy,
    old_LastChange,
    new_LastChange,
    old_CompanyType_CAT,
    new_CompanyType_CAT,
    old_LineOfBusiness_CAT,
    new_LineOfBusiness_CAT,
    old_BillingMethod_CAT,
    new_BillingMethod_CAT,
    old_PaymentMethod_CAT,
    new_PaymentMethod_CAT,
    old_Domicile_CAT,
    new_Domicile_CAT,
    old_Region_CAT,
    new_Region_CAT,
    old_SubType_CAT,
    new_SubType_CAT,
    Transaction_ID,
    TransactionType,
    TransactionUser,
    TransactionDate
)
select 
old_Company_ID,
    new_Company_ID,
    old_AlternateName,
    new_AlternateName,
    old_AdministrationNumber,
    new_AdministrationNumber,
    old_InternalNumber,
    new_InternalNumber,
    old_FiscalYearEnd,
    new_FiscalYearEnd,
    old_TaxYearEnd,
    new_TaxYearEnd,
    old_HasEmployees,
    new_HasEmployees,
    old_Purpose_ID,
    new_Purpose_ID,
    old_AgreementDate,
    new_AgreementDate,
    old_TerminationDate,
    new_TerminationDate,
    old_AnnualMeetingMonth,
    new_AnnualMeetingMonth,
    old_AnnualMeetingNotes_ID,
    new_AnnualMeetingNotes_ID,
    old_AnnualMeetingDate,
    new_AnnualMeetingDate,
    old_DirectorsMin,
    new_DirectorsMin,
    old_DirectorsMax,
    new_DirectorsMax,
    old_DirectorsAuthorized,
    new_DirectorsAuthorized,
    old_DirectorsQuorum,
    new_DirectorsQuorum,
    old_BoardClasses,
    new_BoardClasses,
    old_BooksLocation,
    new_BooksLocation,
    old_SealLocation,
    new_SealLocation,
    old_Successor_EID,
    new_Successor_EID,
    old_Comments_ID,
    new_Comments_ID,
    old_DirectorsComments_ID,
    new_DirectorsComments_ID,
    old_LastMeetingDate,
    new_LastMeetingDate,
    old_CorpStatusDate,
    new_CorpStatusDate,
    old_LLCGovernedBy,
    new_LLCGovernedBy,
    old_CompanyType_CD,
    new_CompanyType_CD,
    old_AccountCode,
    new_AccountCode,
    old_ChargeBackPct,
    new_ChargeBackPct,
    old_ChargeBackBeginDate,
    new_ChargeBackBeginDate,
    old_ChargeBackCode1,
    new_ChargeBackCode1,
    old_ChargeBackCode2,
    new_ChargeBackCode2,
    old_ChargeBackCode3,
    new_ChargeBackCode3,
    old_LineOfBusiness_CD,
    new_LineOfBusiness_CD,
    old_IsInsuranceCompany,
    new_IsInsuranceCompany,
    old_IsBillingEntity,
    new_IsBillingEntity,
    old_ExternalEntityNumber,
    new_ExternalEntityNumber,
	old_eInvoicingVendorID,
    new_eInvoicingVendorID,
    old_ApprovedFirm,
	new_ApprovedFirm,
    old_ApprovedDate,
    new_ApprovedDate,
    old_DismissalDate,
    new_DismissalDate,
    old_BillsCustomer,
    new_BillsCustomer,
    old_BillingMethod_CD,
    new_BillingMethod_CD,
    old_PaymentMethod_CD,
    new_PaymentMethod_CD,
    old_GuidelinesReturned,
    new_GuidelinesReturned,
    old_DateGuidelinesReturned,
    new_DateGuidelinesReturned,
    old_FemaleOwnership,
    new_FemaleOwnership,
    old_MinorityFirm,
    new_MinorityFirm,
    old_Domicile_CD,
    new_Domicile_CD,
    old_Region_CD,
    new_Region_CD,
    old_SubType_CD,
    new_SubType_CD,
    old_Reject,
    new_Reject,
    old_BeginDate,
    new_BeginDate,
    old_EndDate,
    new_EndDate,
    old_ChangeBy,
    new_ChangeBy,
    old_LastChange,
    new_LastChange,
    old_CompanyType_CAT,
    new_CompanyType_CAT,
    old_LineOfBusiness_CAT,
    new_LineOfBusiness_CAT,
    old_BillingMethod_CAT,
    new_BillingMethod_CAT,
    old_PaymentMethod_CAT,
    new_PaymentMethod_CAT,
    old_Domicile_CAT,
    new_Domicile_CAT,
    old_Region_CAT,
    new_Region_CAT,
    old_SubType_CAT,
    new_SubType_CAT,
    Transaction_ID,
    TransactionType,
    TransactionUser,
    TransactionDate from Company_Audit	  
	  ';
	  COMMIT;
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Company';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE 'drop table Company_Audit cascade constraints';
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Company';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
'
create table Company_Audit
(
    old_Company_ID                       NUMBER(10,0)   null,
    new_Company_ID                       NUMBER(10,0)   null,
    old_AlternateName                    VARCHAR2(150)  null,
    new_AlternateName                    VARCHAR2(150)  null,
    old_AdministrationNumber             VARCHAR2(20)   null,
    new_AdministrationNumber             VARCHAR2(20)   null,
    old_InternalNumber                   VARCHAR2(40)   null,
    new_InternalNumber                   VARCHAR2(40)   null,
    old_FiscalYearEnd                    VARCHAR2(40)   null,
    new_FiscalYearEnd                    VARCHAR2(40)   null,
    old_TaxYearEnd                       VARCHAR2(40)   null,
    new_TaxYearEnd                       VARCHAR2(40)   null,
    old_HasEmployees                     CHAR(1)        null,
    new_HasEmployees                     CHAR(1)        null,
    old_Purpose_ID                       NUMBER(10,0)   null,
    new_Purpose_ID                       NUMBER(10,0)   null,
    old_AgreementDate                    DATE           null,
    new_AgreementDate                    DATE           null,
    old_TerminationDate                  DATE           null,
    new_TerminationDate                  DATE           null,
    old_AnnualMeetingMonth               NUMBER(10,0)   null,
    new_AnnualMeetingMonth               NUMBER(10,0)   null,
    old_AnnualMeetingNotes_ID            NUMBER(10,0)   null,
    new_AnnualMeetingNotes_ID            NUMBER(10,0)   null,
    old_AnnualMeetingDate                DATE           null,
    new_AnnualMeetingDate                DATE           null,
    old_DirectorsMin                     NUMBER(10,0)   null,
    new_DirectorsMin                     NUMBER(10,0)   null,
    old_DirectorsMax                     NUMBER(10,0)   null,
    new_DirectorsMax                     NUMBER(10,0)   null,
    old_DirectorsAuthorized              NUMBER(10,0)   null,
    new_DirectorsAuthorized              NUMBER(10,0)   null,
    old_DirectorsQuorum                  VARCHAR2(255)  null,
    new_DirectorsQuorum                  VARCHAR2(255)  null,
    old_BoardClasses                     NUMBER(10,0)   null,
    new_BoardClasses                     NUMBER(10,0)   null,
    old_BooksLocation                    VARCHAR2(255)  null,
    new_BooksLocation                    VARCHAR2(255)  null,
    old_SealLocation                     VARCHAR2(255)  null,
    new_SealLocation                     VARCHAR2(255)  null,
    old_Successor_EID                    NUMBER(10,0)   null,
    new_Successor_EID                    NUMBER(10,0)   null,
    old_Comments_ID                      NUMBER(10,0)   null,
    new_Comments_ID                      NUMBER(10,0)   null,
    old_DirectorsComments_ID             NUMBER(10,0)   null,
    new_DirectorsComments_ID             NUMBER(10,0)   null,
    old_LastMeetingDate                  DATE           null,
    new_LastMeetingDate                  DATE           null,
    old_CorpStatusDate                   DATE           null,
    new_CorpStatusDate                   DATE           null,
    old_LLCGovernedBy                    NUMBER(10,0)   null,
    new_LLCGovernedBy                    NUMBER(10,0)   null,
    old_CompanyType_CD                   VARCHAR2(40)   null,
    new_CompanyType_CD                   VARCHAR2(40)   null,
    old_AccountCode                      VARCHAR2(40)   null,
    new_AccountCode                      VARCHAR2(40)   null,
    old_ChargeBackPct                    NUMBER(10,4)   null,
    new_ChargeBackPct                    NUMBER(10,4)   null,
    old_ChargeBackBeginDate              DATE           null,
    new_ChargeBackBeginDate              DATE           null,
    old_ChargeBackCode1                  VARCHAR2(100)   null,
    new_ChargeBackCode1                  VARCHAR2(100)   null,
    old_ChargeBackCode2                  VARCHAR2(100)   null,
    new_ChargeBackCode2                  VARCHAR2(100)   null,
    old_ChargeBackCode3                  VARCHAR2(100)   null,
    new_ChargeBackCode3                  VARCHAR2(100)   null,
    old_LineOfBusiness_CD                VARCHAR2(40)   null,
    new_LineOfBusiness_CD                VARCHAR2(40)   null,
    old_IsInsuranceCompany               CHAR(1)        null,
    new_IsInsuranceCompany               CHAR(1)        null,
    old_IsBillingEntity                  CHAR(1)        null,
    new_IsBillingEntity                  CHAR(1)        null,
    old_ExternalEntityNumber             VARCHAR2(20)   null,
    new_ExternalEntityNumber             VARCHAR2(20)   null,
	old_eInvoicingVendorID               VARCHAR2(50)   null,
    new_eInvoicingVendorID               VARCHAR2(50)   null,
	old_LHOrganizationID				 VARCHAR2(50)	null,
	new_LHOrganizationID				 VARCHAR2(50)	null,
    old_ApprovedFirm                     CHAR(1)        null,
    new_ApprovedFirm                     CHAR(1)        null,
    old_ApprovedDate                     DATE           null,
    new_ApprovedDate                     DATE           null,
    old_DismissalDate                    DATE           null,
    new_DismissalDate                    DATE           null,
    old_BillsCustomer                    CHAR(1)        null,
    new_BillsCustomer                    CHAR(1)        null,
    old_BillingMethod_CD                 VARCHAR2(40)   null,
    new_BillingMethod_CD                 VARCHAR2(40)   null,
    old_PaymentMethod_CD                 VARCHAR2(40)   null,
    new_PaymentMethod_CD                 VARCHAR2(40)   null,
    old_GuidelinesReturned               CHAR(1)        null,
    new_GuidelinesReturned               CHAR(1)        null,
    old_DateGuidelinesReturned           DATE           null,
    new_DateGuidelinesReturned           DATE           null,
    old_FemaleOwnership                  CHAR(1)        null,
    new_FemaleOwnership                  CHAR(1)        null,
    old_MinorityFirm                     CHAR(1)        null,
    new_MinorityFirm                     CHAR(1)        null,
    old_Domicile_CD                      VARCHAR2(40)   null,
    new_Domicile_CD                      VARCHAR2(40)   null,
    old_Region_CD                        VARCHAR2(40)   null,
    new_Region_CD                        VARCHAR2(40)   null,
    old_SubType_CD                       VARCHAR2(40)   null,
    new_SubType_CD                       VARCHAR2(40)   null,
    old_Reject                           CHAR(1)        null,
    new_Reject                           CHAR(1)        null,
    old_BeginDate                        DATE           null,
    new_BeginDate                        DATE           null,
    old_EndDate                          DATE           null,
    new_EndDate                          DATE           null,
    old_ChangeBy                         VARCHAR2(20)   null,
    new_ChangeBy                         VARCHAR2(20)   null,
    old_LastChange                       DATE           null,
    new_LastChange                       DATE           null,
    old_CompanyType_CAT                  NUMBER(10,0)   null,
    new_CompanyType_CAT                  NUMBER(10,0)   null,
    old_LineOfBusiness_CAT               NUMBER(10,0)   null,
    new_LineOfBusiness_CAT               NUMBER(10,0)   null,
    old_BillingMethod_CAT                NUMBER(10,0)   null,
    new_BillingMethod_CAT                NUMBER(10,0)   null,
    old_PaymentMethod_CAT                NUMBER(10,0)   null,
    new_PaymentMethod_CAT                NUMBER(10,0)   null,
    old_Domicile_CAT                     NUMBER(10,0)   null,
    new_Domicile_CAT                     NUMBER(10,0)   null,
    old_Region_CAT                       NUMBER(10,0)   null,
    new_Region_CAT                       NUMBER(10,0)   null,
    old_SubType_CAT                      NUMBER(10,0)   null,
    new_SubType_CAT                      NUMBER(10,0)   null,
    Transaction_ID                       NUMBER(27,0)   null,
    TransactionType                      CHAR(1)        null,
    TransactionUser                      VARCHAR2(20)   null,
    TransactionDate                      DATE           null
)';
END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Company';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
        'insert into Company_Audit
         select * from tmp_Company_Audit';
      COMMIT;
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Company';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE 'drop table tmp_Company_Audit';
    END;
  ELSE
    NULL;
  END IF;
END;
/
--Matter

BEGIN
  EXECUTE IMMEDIATE 'drop table tmp_Matter_Audit';
  EXCEPTION
    WHEN OTHERS THEN null;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Matter';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
	  '
create table tmp_Matter_Audit
(
old_MatterNumber_ID                  NUMBER(10,0)   null,
    new_MatterNumber_ID                  NUMBER(10,0)   null,
    old_Matter_CD                        VARCHAR2(40)   null,
    new_Matter_CD                        VARCHAR2(40)   null,
    old_MatterStatus_CD                  VARCHAR2(40)   null,
    new_MatterStatus_CD                  VARCHAR2(40)   null,
    old_LogicalGroup_ID                  NUMBER(10,0)   null,
    new_LogicalGroup_ID                  NUMBER(10,0)   null,
    old_MatterNumber                     VARCHAR2(40)   null,
    new_MatterNumber                     VARCHAR2(40)   null,
    old_MatterName                       VARCHAR2(200)  null,
    new_MatterName                       VARCHAR2(200)  null,
    old_FileNumber                       VARCHAR2(20)   null,
    new_FileNumber                       VARCHAR2(20)   null,
    old_ProductService_CD                VARCHAR2(40)   null,
    new_ProductService_CD                VARCHAR2(40)   null,
    old_SubProductService_CD             VARCHAR2(40)   null,
    new_SubProductService_CD             VARCHAR2(40)   null,
    old_OpenDate                         DATE           null,
    new_OpenDate                         DATE           null,
    old_OpenDate_ID                      NUMBER(10,0)   null,
    new_OpenDate_ID                      NUMBER(10,0)   null,
    old_CloseDate                        DATE           null,
    new_CloseDate                        DATE           null,
    old_CloseDate_ID                     NUMBER(10,0)   null,
    new_CloseDate_ID                     NUMBER(10,0)   null,
    old_ReOpenDate                       DATE           null,
    new_ReOpenDate                       DATE           null,
    old_ReOpenDate_ID                    NUMBER(10,0)   null,
    new_ReOpenDate_ID                    NUMBER(10,0)   null,
    old_Law_CD                           VARCHAR2(40)   null,
    new_Law_CD                           VARCHAR2(40)   null,
    old_SubLaw_CD                        VARCHAR2(40)   null,
    new_SubLaw_CD                        VARCHAR2(40)   null,
    old_LongMatterName_ID                NUMBER(10,0)   null,
    new_LongMatterName_ID                NUMBER(10,0)   null,
    old_LongMatterName                   VARCHAR2(4000) null,
    new_LongMatterName                   VARCHAR2(4000) null,
    old_Comments_ID                      NUMBER(10,0)   null,
    new_Comments_ID                      NUMBER(10,0)   null,
    old_TargetDate                       DATE           null,
    new_TargetDate                       DATE           null,
    old_TargetDate_ID                    NUMBER(10,0)   null,
    new_TargetDate_ID                    NUMBER(10,0)   null,
    old_State_CD                         VARCHAR2(40)   null,
    new_State_CD                         VARCHAR2(40)   null,
    old_Country_CD                       VARCHAR2(40)   null,
    new_Country_CD                       VARCHAR2(40)   null,
    old_Region_CD                        VARCHAR2(40)   null,
    new_Region_CD                        VARCHAR2(40)   null,
    old_Litigated                        CHAR(1)        null,
    new_Litigated                        CHAR(1)        null,
    old_LegalSection_CD                  VARCHAR2(40)   null,
    new_LegalSection_CD                  VARCHAR2(40)   null,
    old_Budgeted                         CHAR(1)        null,
    new_Budgeted                         CHAR(1)        null,
    old_Insured                          CHAR(1)        null,
    new_Insured                          CHAR(1)        null,
    old_AccrueCosts                      CHAR(1)        null,
    new_AccrueCosts                      CHAR(1)        null,
    old_Priority_CD                      VARCHAR2(40)   null,
    new_Priority_CD                      VARCHAR2(40)   null,
    old_PrivateMatter                    CHAR(1)        null,
    new_PrivateMatter                    CHAR(1)        null,
    old_PrivateChangeBy_ID               NUMBER(10,0)   null,
    new_PrivateChangeBy_ID               NUMBER(10,0)   null,
    old_PrivateChangeDate                DATE           null,
    new_PrivateChangeDate                DATE           null,
    old_Exported                         CHAR(1)        null,
    new_Exported                         CHAR(1)        null,
    old_BillAfterClose                   CHAR(1)        null,
    new_BillAfterClose                   CHAR(1)        null,
	old_eInvoicingMatterID               VARCHAR2(50)   null,
    new_eInvoicingMatterID               VARCHAR2(50)   null,
	old_NeedSync                         CHAR(1)        null,
    new_NeedSync                         CHAR(1)        null,
	old_CollaboratiSync                  CHAR(1)        null,
    new_CollaboratiSync                  CHAR(1)        null,
	old_LHMatterID						 VARCHAR2(50)	null,
	new_LHMatterID						 VARCHAR2(50)	null,
	old_ActiveHolds						 NUMBER(10,0)	null,
	new_ActiveHolds						 NUMBER(10,0)	null,
    old_CreatedDate                      DATE           null,
    new_CreatedDate                      DATE           null,
    old_ChangeBy                         VARCHAR2(20)   null,
    new_ChangeBy                         VARCHAR2(20)   null,
    old_LastChange                       DATE           null,
    new_LastChange                       DATE           null,
    old_Matter_CAT                       NUMBER(10,0)   null,
    new_Matter_CAT                       NUMBER(10,0)   null,
    old_MatterStatus_CAT                 NUMBER(10,0)   null,
    new_MatterStatus_CAT                 NUMBER(10,0)   null,
    old_ProductService_CAT               NUMBER(10,0)   null,
    new_ProductService_CAT               NUMBER(10,0)   null,
    old_SubProductService_CAT            NUMBER(10,0)   null,
    new_SubProductService_CAT            NUMBER(10,0)   null,
    old_Law_CAT                          NUMBER(10,0)   null,
    new_Law_CAT                          NUMBER(10,0)   null,
    old_SubLaw_CAT                       NUMBER(10,0)   null,
    new_SubLaw_CAT                       NUMBER(10,0)   null,
    old_State_CAT                        NUMBER(10,0)   null,
    new_State_CAT                        NUMBER(10,0)   null,
    old_Country_CAT                      NUMBER(10,0)   null,
    new_Country_CAT                      NUMBER(10,0)   null,
    old_Region_CAT                       NUMBER(10,0)   null,
    new_Region_CAT                       NUMBER(10,0)   null,
    old_LegalSection_CAT                 NUMBER(10,0)   null,
    new_LegalSection_CAT                 NUMBER(10,0)   null,
    old_Priority_CAT                     NUMBER(10,0)   null,
    new_Priority_CAT                     NUMBER(10,0)   null,
    Transaction_ID                       NUMBER(27,0)   null,
    TransactionType                      CHAR(1)        null,
    TransactionUser                      VARCHAR2(20)   null,
    TransactionDate                      DATE           null
)';
END;
  ELSE
    NULL;
  END IF;
END;
/


DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Matter';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
	  '
insert into tmp_Matter_Audit
(
old_MatterNumber_ID,
    new_MatterNumber_ID,
    old_Matter_CD,
    new_Matter_CD,
    old_MatterStatus_CD,
    new_MatterStatus_CD,
    old_LogicalGroup_ID,
    new_LogicalGroup_ID,
    old_MatterNumber,
    new_MatterNumber,
    old_MatterName,
    new_MatterName,
    old_FileNumber,
    new_FileNumber,
    old_ProductService_CD,
    new_ProductService_CD,
    old_SubProductService_CD,
    new_SubProductService_CD,
    old_OpenDate,
    new_OpenDate,
    old_OpenDate_ID,
    new_OpenDate_ID,
    old_CloseDate,
    new_CloseDate,
    old_CloseDate_ID,
    new_CloseDate_ID,
    old_ReOpenDate,
    new_ReOpenDate,
    old_ReOpenDate_ID,
    new_ReOpenDate_ID,
    old_Law_CD,
    new_Law_CD,
    old_SubLaw_CD,
    new_SubLaw_CD,
    old_LongMatterName_ID,
    new_LongMatterName_ID,
    old_LongMatterName,
    new_LongMatterName,
    old_Comments_ID,
    new_Comments_ID,
    old_TargetDate,
    new_TargetDate,
    old_TargetDate_ID,
    new_TargetDate_ID,
    old_State_CD,
    new_State_CD,
    old_Country_CD,
    new_Country_CD,
    old_Region_CD,
    new_Region_CD,
    old_Litigated,
    new_Litigated,
    old_LegalSection_CD,
    new_LegalSection_CD,
    old_Budgeted,
    new_Budgeted,
    old_Insured,
    new_Insured,
    old_AccrueCosts,
    new_AccrueCosts,
    old_Priority_CD,
    new_Priority_CD,
    old_PrivateMatter,
    new_PrivateMatter,
    old_PrivateChangeBy_ID,
    new_PrivateChangeBy_ID,
    old_PrivateChangeDate,
    new_PrivateChangeDate,
    old_Exported,
    new_Exported,
    old_BillAfterClose,
    new_BillAfterClose,
	old_eInvoicingMatterID,
    new_eInvoicingMatterID,
	old_NeedSync,
    new_NeedSync,
	old_CollaboratiSync,
    new_CollaboratiSync,
	old_CreatedDate,
    new_CreatedDate,
    old_ChangeBy,
    new_ChangeBy,
    old_LastChange,
    new_LastChange,
    old_Matter_CAT,
    new_Matter_CAT,
    old_MatterStatus_CAT,
    new_MatterStatus_CAT,
    old_ProductService_CAT,
    new_ProductService_CAT,
    old_SubProductService_CAT,
    new_SubProductService_CAT,
    old_Law_CAT,
    new_Law_CAT,
    old_SubLaw_CAT,
    new_SubLaw_CAT,
    old_State_CAT,
    new_State_CAT,
    old_Country_CAT,
    new_Country_CAT,
    old_Region_CAT,
    new_Region_CAT,
    old_LegalSection_CAT,
    new_LegalSection_CAT,
    old_Priority_CAT,
    new_Priority_CAT,
    Transaction_ID,
    TransactionType,
    TransactionUser,
    TransactionDate
)
select 
old_MatterNumber_ID,
    new_MatterNumber_ID,
    old_Matter_CD,
    new_Matter_CD,
    old_MatterStatus_CD,
    new_MatterStatus_CD,
    old_LogicalGroup_ID,
    new_LogicalGroup_ID,
    old_MatterNumber,
    new_MatterNumber,
    old_MatterName,
    new_MatterName,
    old_FileNumber,
    new_FileNumber,
    old_ProductService_CD,
    new_ProductService_CD,
    old_SubProductService_CD,
    new_SubProductService_CD,
    old_OpenDate,
    new_OpenDate,
    old_OpenDate_ID,
    new_OpenDate_ID,
    old_CloseDate,
    new_CloseDate,
    old_CloseDate_ID,
    new_CloseDate_ID,
    old_ReOpenDate,
    new_ReOpenDate,
    old_ReOpenDate_ID,
    new_ReOpenDate_ID,
    old_Law_CD,
    new_Law_CD,
    old_SubLaw_CD,
    new_SubLaw_CD,
    old_LongMatterName_ID,
    new_LongMatterName_ID,
    old_LongMatterName,
    new_LongMatterName,
    old_Comments_ID,
    new_Comments_ID,
    old_TargetDate,
    new_TargetDate,
    old_TargetDate_ID,
    new_TargetDate_ID,
    old_State_CD,
    new_State_CD,
    old_Country_CD,
    new_Country_CD,
    old_Region_CD,
    new_Region_CD,
    old_Litigated,
    new_Litigated,
    old_LegalSection_CD,
    new_LegalSection_CD,
    old_Budgeted,
    new_Budgeted,
    old_Insured,
    new_Insured,
    old_AccrueCosts,
    new_AccrueCosts,
    old_Priority_CD,
    new_Priority_CD,
    old_PrivateMatter,
    new_PrivateMatter,
    old_PrivateChangeBy_ID,
    new_PrivateChangeBy_ID,
    old_PrivateChangeDate,
    new_PrivateChangeDate,
    old_Exported,
    new_Exported,
    old_BillAfterClose,
    new_BillAfterClose,
	old_eInvoicingMatterID,
    new_eInvoicingMatterID,
	old_NeedSync,
    new_NeedSync,
	old_CollaboratiSync,
    new_CollaboratiSync,
	old_CreatedDate,
    new_CreatedDate,
    old_ChangeBy,
    new_ChangeBy,
    old_LastChange,
    new_LastChange,
    old_Matter_CAT,
    new_Matter_CAT,
    old_MatterStatus_CAT,
    new_MatterStatus_CAT,
    old_ProductService_CAT,
    new_ProductService_CAT,
    old_SubProductService_CAT,
    new_SubProductService_CAT,
    old_Law_CAT,
    new_Law_CAT,
    old_SubLaw_CAT,
    new_SubLaw_CAT,
    old_State_CAT,
    new_State_CAT,
    old_Country_CAT,
    new_Country_CAT,
    old_Region_CAT,
    new_Region_CAT,
    old_LegalSection_CAT,
    new_LegalSection_CAT,
    old_Priority_CAT,
    new_Priority_CAT,
    Transaction_ID,
    TransactionType,
    TransactionUser,
    TransactionDate
from Matter_Audit	  
	  ';
	  COMMIT;
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Matter';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE 'drop table Matter_Audit cascade constraints';
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Matter';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
'
create table Matter_Audit
(
old_MatterNumber_ID                  NUMBER(10,0)   null,
    new_MatterNumber_ID                  NUMBER(10,0)   null,
    old_Matter_CD                        VARCHAR2(40)   null,
    new_Matter_CD                        VARCHAR2(40)   null,
    old_MatterStatus_CD                  VARCHAR2(40)   null,
    new_MatterStatus_CD                  VARCHAR2(40)   null,
    old_LogicalGroup_ID                  NUMBER(10,0)   null,
    new_LogicalGroup_ID                  NUMBER(10,0)   null,
    old_MatterNumber                     VARCHAR2(40)   null,
    new_MatterNumber                     VARCHAR2(40)   null,
    old_MatterName                       VARCHAR2(200)  null,
    new_MatterName                       VARCHAR2(200)  null,
    old_FileNumber                       VARCHAR2(20)   null,
    new_FileNumber                       VARCHAR2(20)   null,
    old_ProductService_CD                VARCHAR2(40)   null,
    new_ProductService_CD                VARCHAR2(40)   null,
    old_SubProductService_CD             VARCHAR2(40)   null,
    new_SubProductService_CD             VARCHAR2(40)   null,
    old_OpenDate                         DATE           null,
    new_OpenDate                         DATE           null,
    old_OpenDate_ID                      NUMBER(10,0)   null,
    new_OpenDate_ID                      NUMBER(10,0)   null,
    old_CloseDate                        DATE           null,
    new_CloseDate                        DATE           null,
    old_CloseDate_ID                     NUMBER(10,0)   null,
    new_CloseDate_ID                     NUMBER(10,0)   null,
    old_ReOpenDate                       DATE           null,
    new_ReOpenDate                       DATE           null,
    old_ReOpenDate_ID                    NUMBER(10,0)   null,
    new_ReOpenDate_ID                    NUMBER(10,0)   null,
    old_Law_CD                           VARCHAR2(40)   null,
    new_Law_CD                           VARCHAR2(40)   null,
    old_SubLaw_CD                        VARCHAR2(40)   null,
    new_SubLaw_CD                        VARCHAR2(40)   null,
    old_LongMatterName_ID                NUMBER(10,0)   null,
    new_LongMatterName_ID                NUMBER(10,0)   null,
    old_LongMatterName                   VARCHAR2(4000) null,
    new_LongMatterName                   VARCHAR2(4000) null,
    old_Comments_ID                      NUMBER(10,0)   null,
    new_Comments_ID                      NUMBER(10,0)   null,
    old_TargetDate                       DATE           null,
    new_TargetDate                       DATE           null,
    old_TargetDate_ID                    NUMBER(10,0)   null,
    new_TargetDate_ID                    NUMBER(10,0)   null,
    old_State_CD                         VARCHAR2(40)   null,
    new_State_CD                         VARCHAR2(40)   null,
    old_Country_CD                       VARCHAR2(40)   null,
    new_Country_CD                       VARCHAR2(40)   null,
    old_Region_CD                        VARCHAR2(40)   null,
    new_Region_CD                        VARCHAR2(40)   null,
    old_Litigated                        CHAR(1)        null,
    new_Litigated                        CHAR(1)        null,
    old_LegalSection_CD                  VARCHAR2(40)   null,
    new_LegalSection_CD                  VARCHAR2(40)   null,
    old_Budgeted                         CHAR(1)        null,
    new_Budgeted                         CHAR(1)        null,
    old_Insured                          CHAR(1)        null,
    new_Insured                          CHAR(1)        null,
    old_AccrueCosts                      CHAR(1)        null,
    new_AccrueCosts                      CHAR(1)        null,
    old_Priority_CD                      VARCHAR2(40)   null,
    new_Priority_CD                      VARCHAR2(40)   null,
    old_PrivateMatter                    CHAR(1)        null,
    new_PrivateMatter                    CHAR(1)        null,
    old_PrivateChangeBy_ID               NUMBER(10,0)   null,
    new_PrivateChangeBy_ID               NUMBER(10,0)   null,
    old_PrivateChangeDate                DATE           null,
    new_PrivateChangeDate                DATE           null,
    old_Exported                         CHAR(1)        null,
    new_Exported                         CHAR(1)        null,
    old_BillAfterClose                   CHAR(1)        null,
    new_BillAfterClose                   CHAR(1)        null,
	old_eInvoicingMatterID               VARCHAR2(50)   null,
    new_eInvoicingMatterID               VARCHAR2(50)   null,
	old_NeedSync                         CHAR(1)        null,
    new_NeedSync                         CHAR(1)        null,
	old_CollaboratiSync                  CHAR(1)        null,
    new_CollaboratiSync                  CHAR(1)        null,
	old_LHMatterID						 VARCHAR2(50)	null,
	new_LHMatterID						 VARCHAR2(50)	null,
	old_ActiveHolds						 NUMBER(10,0)	null,
	new_ActiveHolds						 NUMBER(10,0)	null,
    old_CreatedDate                      DATE           null,
    new_CreatedDate                      DATE           null,
    old_ChangeBy                         VARCHAR2(20)   null,
    new_ChangeBy                         VARCHAR2(20)   null,
    old_LastChange                       DATE           null,
    new_LastChange                       DATE           null,
    old_Matter_CAT                       NUMBER(10,0)   null,
    new_Matter_CAT                       NUMBER(10,0)   null,
    old_MatterStatus_CAT                 NUMBER(10,0)   null,
    new_MatterStatus_CAT                 NUMBER(10,0)   null,
    old_ProductService_CAT               NUMBER(10,0)   null,
    new_ProductService_CAT               NUMBER(10,0)   null,
    old_SubProductService_CAT            NUMBER(10,0)   null,
    new_SubProductService_CAT            NUMBER(10,0)   null,
    old_Law_CAT                          NUMBER(10,0)   null,
    new_Law_CAT                          NUMBER(10,0)   null,
    old_SubLaw_CAT                       NUMBER(10,0)   null,
    new_SubLaw_CAT                       NUMBER(10,0)   null,
    old_State_CAT                        NUMBER(10,0)   null,
    new_State_CAT                        NUMBER(10,0)   null,
    old_Country_CAT                      NUMBER(10,0)   null,
    new_Country_CAT                      NUMBER(10,0)   null,
    old_Region_CAT                       NUMBER(10,0)   null,
    new_Region_CAT                       NUMBER(10,0)   null,
    old_LegalSection_CAT                 NUMBER(10,0)   null,
    new_LegalSection_CAT                 NUMBER(10,0)   null,
    old_Priority_CAT                     NUMBER(10,0)   null,
    new_Priority_CAT                     NUMBER(10,0)   null,
    Transaction_ID                       NUMBER(27,0)   null,
    TransactionType                      CHAR(1)        null,
    TransactionUser                      VARCHAR2(20)   null,
    TransactionDate                      DATE           null
   
)';
END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Matter';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
        'insert into Matter_Audit
         select * from tmp_Matter_Audit';
      COMMIT;
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Matter';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE 'drop table tmp_Matter_Audit';
    END;
  ELSE
    NULL;
  END IF;
END;
/

--PERSON_AUDIT

BEGIN
  EXECUTE IMMEDIATE 'drop table tmp_Person_Audit';
  EXCEPTION
    WHEN OTHERS THEN null;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Person';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
	  '
create table tmp_Person_Audit
(
old_Person_ID                        NUMBER(10,0)   null,
    new_Person_ID                        NUMBER(10,0)   null,
    old_LastName                         VARCHAR2(30)   null,
    new_LastName                         VARCHAR2(30)   null,
    old_FirstName                        VARCHAR2(30)   null,
    new_FirstName                        VARCHAR2(30)   null,
    old_Middle                           VARCHAR2(30)   null,
    new_Middle                           VARCHAR2(30)   null,
    old_Suffix                           VARCHAR2(20)   null,
    new_Suffix                           VARCHAR2(20)   null,
    old_Salutation                       VARCHAR2(15)   null,
    new_Salutation                       VARCHAR2(15)   null,
    old_Nickname                         VARCHAR2(15)   null,
    new_Nickname                         VARCHAR2(15)   null,
	old_Initials                         VARCHAR2(8)    null,
    new_Initials                         VARCHAR2(8)    null,
    old_AdministrationNumber             VARCHAR2(20)   null,
    new_AdministrationNumber             VARCHAR2(20)   null,
    old_Employee                         CHAR(1)        null,
    new_Employee                         CHAR(1)        null,
    old_EmployeeStartDate                DATE           null,
    new_EmployeeStartDate                DATE           null,
    old_EmployeeEndDate                  DATE           null,
    new_EmployeeEndDate                  DATE           null,
    old_Spouse                           VARCHAR2(40)   null,
    new_Spouse                           VARCHAR2(40)   null,
    old_SpouseSSN                        VARCHAR2(20)   null,
    new_SpouseSSN                        VARCHAR2(20)   null,
    old_Gender                           CHAR(1)        null,
    new_Gender                           CHAR(1)        null,
    old_EthnicClassification_CD          VARCHAR2(40)   null,
    new_EthnicClassification_CD          VARCHAR2(40)   null,
    old_Secretary                        VARCHAR2(40)   null,
    new_Secretary                        VARCHAR2(40)   null,
    old_BirthDate                        DATE           null,
    new_BirthDate                        DATE           null,
    old_BirthPlace                       VARCHAR2(100)  null,
    new_BirthPlace                       VARCHAR2(100)  null,
    old_DeathDate                        DATE           null,
    new_DeathDate                        DATE           null,
    old_SecurityLevel                    NUMBER(10,0)   null,
    new_SecurityLevel                    NUMBER(10,0)   null,
    old_CitizenJurisdiction_ID           NUMBER(10,0)   null,
    new_CitizenJurisdiction_ID           NUMBER(10,0)   null,
    old_PassportNumber                   VARCHAR2(40)   null,
    new_PassportNumber                   VARCHAR2(40)   null,
    old_DriversLicense                   VARCHAR2(20)   null,
    new_DriversLicense                   VARCHAR2(20)   null,
    old_DriversLicenseJuris_ID           NUMBER(10,0)   null,
    new_DriversLicenseJuris_ID           NUMBER(10,0)   null,
    old_Timekeeper                       CHAR(1)        null,
    new_Timekeeper                       CHAR(1)        null,
    old_AssociatedTimekeeperID           VARCHAR2(100)  null,
    new_AssociatedTimekeeperID           VARCHAR2(100)  null,
    old_TimekeeperSync                   CHAR(1)        null,
    new_TimekeeperSync                   CHAR(1)        null,
    old_eInvoicingTimekeeperID			 VARCHAR2(50)   null,
	new_eInvoicingTimekeeperID			 VARCHAR2(50)   null,
    old_eInvoicingAuthorized             CHAR(1)        null,
    new_eInvoicingAuthorized             CHAR(1)        null,
    old_StartOfWeek                      VARCHAR2(15)   null,
    new_StartOfWeek                      VARCHAR2(15)   null,
    old_DailyMinumumHours                NUMBER(10,4)   null,
    new_DailyMinumumHours                NUMBER(10,4)   null,
    old_DailyMaximumHours                NUMBER(10,4)   null,
    new_DailyMaximumHours                NUMBER(10,4)   null,
    old_WeeklyMinimumHours               NUMBER(10,4)   null,
    new_WeeklyMinimumHours               NUMBER(10,4)   null,
    old_WeeklyMaximumHours               NUMBER(10,4)   null,
    new_WeeklyMaximumHours               NUMBER(10,4)   null,
    old_TimekeeperComments_ID            NUMBER(10,0)   null,
    new_TimekeeperComments_ID            NUMBER(10,0)   null,
	old_LHLegalHoldStaffID				 VARCHAR2(50)	null,
	new_LHLegalHoldStaffID				 VARCHAR2(50)	null,
    old_Comments_ID                      NUMBER(10,0)   null,
	new_Comments_ID                      NUMBER(10,0)   null,
    old_ChangeBy                         VARCHAR2(20)   null,
    new_ChangeBy                         VARCHAR2(20)   null,
    old_LastChange                       DATE           null,
    new_LastChange                       DATE           null,
    old_EthnicClassification_CAT         NUMBER(10,0)   null,
    new_EthnicClassification_CAT         NUMBER(10,0)   null,
    Transaction_ID                       NUMBER(27,0)   null,
    TransactionType                      CHAR(1)        null,
    TransactionUser                      VARCHAR2(20)   null,
    TransactionDate                      DATE           null
)';
END;
  ELSE
    NULL;
  END IF;
END;
/


DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Person';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
	  '
insert into tmp_Person_Audit
(
old_Person_ID,
    new_Person_ID,
    old_LastName,
    new_LastName,
    old_FirstName,
    new_FirstName,
    old_Middle,
    new_Middle,
    old_Suffix,
    new_Suffix,
    old_Salutation,
    new_Salutation,
    old_Nickname,
    new_Nickname,
	old_Initials,
    new_Initials,
    old_AdministrationNumber,
    new_AdministrationNumber,
    old_Employee,
    new_Employee,
    old_EmployeeStartDate,
    new_EmployeeStartDate,
    old_EmployeeEndDate,
    new_EmployeeEndDate,
    old_Spouse,
    new_Spouse,
    old_SpouseSSN,
    new_SpouseSSN,
    old_Gender,
    new_Gender,
    old_EthnicClassification_CD,
    new_EthnicClassification_CD,
    old_Secretary,
    new_Secretary,
    old_BirthDate,
    new_BirthDate,
    old_BirthPlace,
    new_BirthPlace,
    old_DeathDate,
    new_DeathDate,
    old_SecurityLevel,
    new_SecurityLevel,
    old_CitizenJurisdiction_ID,
    new_CitizenJurisdiction_ID,
    old_PassportNumber,
    new_PassportNumber,
    old_DriversLicense,
    new_DriversLicense,
    old_DriversLicenseJuris_ID,
    new_DriversLicenseJuris_ID,
    old_Timekeeper,
    new_Timekeeper,
    old_AssociatedTimekeeperID,
    new_AssociatedTimekeeperID,
    old_TimekeeperSync,
    new_TimekeeperSync,
    old_eInvoicingTimekeeperID,
	new_eInvoicingTimekeeperID,
    old_eInvoicingAuthorized,
    new_eInvoicingAuthorized,
    old_StartOfWeek,
    new_StartOfWeek,
    old_DailyMinumumHours,
    new_DailyMinumumHours,
    old_DailyMaximumHours,
    new_DailyMaximumHours,
    old_WeeklyMinimumHours,
    new_WeeklyMinimumHours,
    old_WeeklyMaximumHours,
    new_WeeklyMaximumHours,
    old_TimekeeperComments_ID,
    new_TimekeeperComments_ID,
    old_Comments_ID,
	new_Comments_ID,
    old_ChangeBy,
    new_ChangeBy,
    old_LastChange,
    new_LastChange,
    old_EthnicClassification_CAT,
    new_EthnicClassification_CAT,
    Transaction_ID,
    TransactionType,
    TransactionUser,
    TransactionDate
)
select 
old_Person_ID,
    new_Person_ID,
    old_LastName,
    new_LastName,
    old_FirstName,
    new_FirstName,
    old_Middle,
    new_Middle,
    old_Suffix,
    new_Suffix,
    old_Salutation,
    new_Salutation,
    old_Nickname,
    new_Nickname,
	old_Initials,
    new_Initials,
    old_AdministrationNumber,
    new_AdministrationNumber,
    old_Employee,
    new_Employee,
    old_EmployeeStartDate,
    new_EmployeeStartDate,
    old_EmployeeEndDate,
    new_EmployeeEndDate,
    old_Spouse,
    new_Spouse,
    old_SpouseSSN,
    new_SpouseSSN,
    old_Gender,
    new_Gender,
    old_EthnicClassification_CD,
    new_EthnicClassification_CD,
    old_Secretary,
    new_Secretary,
    old_BirthDate,
    new_BirthDate,
    old_BirthPlace,
    new_BirthPlace,
    old_DeathDate,
    new_DeathDate,
    old_SecurityLevel,
    new_SecurityLevel,
    old_CitizenJurisdiction_ID,
    new_CitizenJurisdiction_ID,
    old_PassportNumber,
    new_PassportNumber,
    old_DriversLicense,
    new_DriversLicense,
    old_DriversLicenseJuris_ID,
    new_DriversLicenseJuris_ID,
    old_Timekeeper,
    new_Timekeeper,
    old_AssociatedTimekeeperID,
    new_AssociatedTimekeeperID,
    old_TimekeeperSync,
    new_TimekeeperSync,
    old_eInvoicingTimekeeperID,
	new_eInvoicingTimekeeperID,
    old_eInvoicingAuthorized,
    new_eInvoicingAuthorized,
    old_StartOfWeek,
    new_StartOfWeek,
    old_DailyMinumumHours,
    new_DailyMinumumHours,
    old_DailyMaximumHours,
    new_DailyMaximumHours,
    old_WeeklyMinimumHours,
    new_WeeklyMinimumHours,
    old_WeeklyMaximumHours,
    new_WeeklyMaximumHours,
    old_TimekeeperComments_ID,
    new_TimekeeperComments_ID,
    old_Comments_ID,
	new_Comments_ID,
    old_ChangeBy,
    new_ChangeBy,
    old_LastChange,
    new_LastChange,
    old_EthnicClassification_CAT,
    new_EthnicClassification_CAT,
    Transaction_ID,
    TransactionType,
    TransactionUser,
    TransactionDate
from Person_Audit	  
	  ';
	  COMMIT;
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Person';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE 'drop table Person_Audit cascade constraints';
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Person';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
'
create table Person_Audit
(
old_Person_ID                        NUMBER(10,0)   null,
    new_Person_ID                        NUMBER(10,0)   null,
    old_LastName                         VARCHAR2(30)   null,
    new_LastName                         VARCHAR2(30)   null,
    old_FirstName                        VARCHAR2(30)   null,
    new_FirstName                        VARCHAR2(30)   null,
    old_Middle                           VARCHAR2(30)   null,
    new_Middle                           VARCHAR2(30)   null,
    old_Suffix                           VARCHAR2(20)   null,
    new_Suffix                           VARCHAR2(20)   null,
    old_Salutation                       VARCHAR2(15)   null,
    new_Salutation                       VARCHAR2(15)   null,
    old_Nickname                         VARCHAR2(15)   null,
    new_Nickname                         VARCHAR2(15)   null,
	old_Initials                         VARCHAR2(8)    null,
    new_Initials                         VARCHAR2(8)    null,
    old_AdministrationNumber             VARCHAR2(20)   null,
    new_AdministrationNumber             VARCHAR2(20)   null,
    old_Employee                         CHAR(1)        null,
    new_Employee                         CHAR(1)        null,
    old_EmployeeStartDate                DATE           null,
    new_EmployeeStartDate                DATE           null,
    old_EmployeeEndDate                  DATE           null,
    new_EmployeeEndDate                  DATE           null,
    old_Spouse                           VARCHAR2(40)   null,
    new_Spouse                           VARCHAR2(40)   null,
    old_SpouseSSN                        VARCHAR2(20)   null,
    new_SpouseSSN                        VARCHAR2(20)   null,
    old_Gender                           CHAR(1)        null,
    new_Gender                           CHAR(1)        null,
    old_EthnicClassification_CD          VARCHAR2(40)   null,
    new_EthnicClassification_CD          VARCHAR2(40)   null,
    old_Secretary                        VARCHAR2(40)   null,
    new_Secretary                        VARCHAR2(40)   null,
    old_BirthDate                        DATE           null,
    new_BirthDate                        DATE           null,
    old_BirthPlace                       VARCHAR2(100)  null,
    new_BirthPlace                       VARCHAR2(100)  null,
    old_DeathDate                        DATE           null,
    new_DeathDate                        DATE           null,
    old_SecurityLevel                    NUMBER(10,0)   null,
    new_SecurityLevel                    NUMBER(10,0)   null,
    old_CitizenJurisdiction_ID           NUMBER(10,0)   null,
    new_CitizenJurisdiction_ID           NUMBER(10,0)   null,
    old_PassportNumber                   VARCHAR2(40)   null,
    new_PassportNumber                   VARCHAR2(40)   null,
    old_DriversLicense                   VARCHAR2(20)   null,
    new_DriversLicense                   VARCHAR2(20)   null,
    old_DriversLicenseJuris_ID           NUMBER(10,0)   null,
    new_DriversLicenseJuris_ID           NUMBER(10,0)   null,
    old_Timekeeper                       CHAR(1)        null,
    new_Timekeeper                       CHAR(1)        null,
    old_AssociatedTimekeeperID           VARCHAR2(100)  null,
    new_AssociatedTimekeeperID           VARCHAR2(100)  null,
    old_TimekeeperSync                   CHAR(1)        null,
    new_TimekeeperSync                   CHAR(1)        null,
    old_eInvoicingTimekeeperID			 VARCHAR2(50)   null,
	new_eInvoicingTimekeeperID			 VARCHAR2(50)   null,
    old_eInvoicingAuthorized             CHAR(1)        null,
    new_eInvoicingAuthorized             CHAR(1)        null,
    old_StartOfWeek                      VARCHAR2(15)   null,
    new_StartOfWeek                      VARCHAR2(15)   null,
    old_DailyMinumumHours                NUMBER(10,4)   null,
    new_DailyMinumumHours                NUMBER(10,4)   null,
    old_DailyMaximumHours                NUMBER(10,4)   null,
    new_DailyMaximumHours                NUMBER(10,4)   null,
    old_WeeklyMinimumHours               NUMBER(10,4)   null,
    new_WeeklyMinimumHours               NUMBER(10,4)   null,
    old_WeeklyMaximumHours               NUMBER(10,4)   null,
    new_WeeklyMaximumHours               NUMBER(10,4)   null,
    old_TimekeeperComments_ID            NUMBER(10,0)   null,
    new_TimekeeperComments_ID            NUMBER(10,0)   null,
	old_LHLegalHoldStaffID				 VARCHAR2(50)	null,
	new_LHLegalHoldStaffID				 VARCHAR2(50)	null,
    old_Comments_ID                      NUMBER(10,0)   null,
	new_Comments_ID                      NUMBER(10,0)   null,
    old_ChangeBy                         VARCHAR2(20)   null,
    new_ChangeBy                         VARCHAR2(20)   null,
    old_LastChange                       DATE           null,
    new_LastChange                       DATE           null,
    old_EthnicClassification_CAT         NUMBER(10,0)   null,
    new_EthnicClassification_CAT         NUMBER(10,0)   null,
    Transaction_ID                       NUMBER(27,0)   null,
    TransactionType                      CHAR(1)        null,
    TransactionUser                      VARCHAR2(20)   null,
    TransactionDate                      DATE           null
)';
END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Person';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
        'insert into Person_Audit
         select * from tmp_Person_Audit';
      COMMIT;
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Person';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE 'drop table tmp_Person_Audit';
    END;
  ELSE
    NULL;
  END IF;
END;
/

--- end audit table section


---Begin audit trigger section

--Audit_Company_trigger
DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTrigger
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Company';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
	  '
	  CREATE OR REPLACE TRIGGER AUDIT_COMPANY
  BEFORE INSERT OR DELETE OR UPDATE ON COMPANY
  FOR EACH ROW
DECLARE
  v_UserSID            NUMBER(10,0);
  v_AuditUserSID       NUMBER(10,0);
  v_LoginDate          DATE;
  v_LoginName          VARCHAR2(20);
  v_TransactionDate    DATE;

  CURSOR c_AuditUserSID IS
    SELECT UserSID, LoginDate
      FROM AuditUserSID;

BEGIN
  SELECT SYSDATE
    INTO v_TransactionDate
    FROM DUAL;

  SELECT DISTINCT(SID)
    INTO v_UserSID
    FROM V$MYSTAT;

  OPEN c_AuditUserSID;
  LOOP
    FETCH c_AuditUserSID
      INTO v_AuditUserSID, v_LoginDate;
    EXIT WHEN c_AuditUserSID%NOTFOUND;

    IF v_UserSID = v_AuditUserSID and v_LoginDate > (SYSDATE-5/24/60) THEN
      SELECT LoginName
        INTO v_LoginName
        FROM AuditUserSID
        WHERE UserSID = v_UserSID;
      ELSE
        NULL;
    END IF;
  END LOOP;
  CLOSE c_AuditUserSID;

  IF v_LoginName IS NULL THEN
     v_LoginName := ''Unknown'';
    ELSE
      NULL;
  END IF;
  IF INSERTING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''I'', v_LoginName, v_TransactionDate, ''COMPANY'');
    INSERT INTO Company_Audit
      (
       new_AccountCode,
       new_AdministrationNumber,
       new_AgreementDate,
       new_AlternateName,
       new_AnnualMeetingDate,
       new_AnnualMeetingMonth,
       new_AnnualMeetingNotes_ID,
       new_ApprovedDate,
       new_ApprovedFirm,
       new_BeginDate,
       new_BillingMethod_CAT,
       new_BillingMethod_CD,
       new_BillsCustomer,
       new_BoardClasses,
       new_BooksLocation,
       new_ChangeBy,
       new_ChargeBackBeginDate,
       new_ChargeBackCode1,
       new_ChargeBackCode2,
       new_ChargeBackCode3,
       new_ChargeBackPct,
       new_Comments_ID,
       new_Company_ID,
       new_CompanyType_CAT,
       new_CompanyType_CD,
       new_CorpStatusDate,
       new_DateGuidelinesReturned,
       new_DirectorsAuthorized,
       new_DirectorsComments_ID,
       new_DirectorsMax,
       new_DirectorsMin,
       new_DirectorsQuorum,
       new_DismissalDate,
       new_Domicile_CAT,
       new_Domicile_CD,
       new_EndDate,
       new_ExternalEntityNumber,
	   new_eInvoicingVendorID,
       new_FemaleOwnership,
       new_FiscalYearEnd,
       new_GuidelinesReturned,
       new_HasEmployees,
       new_InternalNumber,
       new_IsBillingEntity,
       new_IsInsuranceCompany,
       new_LastChange,
       new_LastMeetingDate,
	   new_LHorganizationID,
       new_LineOfBusiness_CAT,
       new_LineOfBusiness_CD,
       new_LLCGovernedBy,
       new_MinorityFirm,
       new_PaymentMethod_CAT,
       new_PaymentMethod_CD,
       new_Purpose_ID,
       new_Region_CAT,
       new_Region_CD,
       new_Reject,
       new_SealLocation,
       new_SubType_CAT,
       new_SubType_CD,
       new_Successor_EID,
       new_TaxYearEnd,
       new_TerminationDate,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :new.AccountCode,
       :new.AdministrationNumber,
       :new.AgreementDate,
       :new.AlternateName,
       :new.AnnualMeetingDate,
       :new.AnnualMeetingMonth,
       :new.AnnualMeetingNotes_ID,
       :new.ApprovedDate,
       :new.ApprovedFirm,
       :new.BeginDate,
       :new.BillingMethod_CAT,
       :new.BillingMethod_CD,
       :new.BillsCustomer,
       :new.BoardClasses,
       :new.BooksLocation,
       :new.ChangeBy,
       :new.ChargeBackBeginDate,
       :new.ChargeBackCode1,
       :new.ChargeBackCode2,
       :new.ChargeBackCode3,
       :new.ChargeBackPct,
       :new.Comments_ID,
       :new.Company_ID,
       :new.CompanyType_CAT,
       :new.CompanyType_CD,
       :new.CorpStatusDate,
       :new.DateGuidelinesReturned,
       :new.DirectorsAuthorized,
       :new.DirectorsComments_ID,
       :new.DirectorsMax,
       :new.DirectorsMin,
       :new.DirectorsQuorum,
       :new.DismissalDate,
       :new.Domicile_CAT,
       :new.Domicile_CD,
       :new.EndDate,
       :new.ExternalEntityNumber,
	   :new.eInvoicingVendorID,
       :new.FemaleOwnership,
       :new.FiscalYearEnd,
       :new.GuidelinesReturned,
       :new.HasEmployees,
       :new.InternalNumber,
       :new.IsBillingEntity,
       :new.IsInsuranceCompany,
       :new.LastChange,
	   :new.LHorganizationID,
       :new.LastMeetingDate,
       :new.LineOfBusiness_CAT,
       :new.LineOfBusiness_CD,
       :new.LLCGovernedBy,
       :new.MinorityFirm,
       :new.PaymentMethod_CAT,
       :new.PaymentMethod_CD,
       :new.Purpose_ID,
       :new.Region_CAT,
       :new.Region_CD,
       :new.Reject,
       :new.SealLocation,
       :new.SubType_CAT,
       :new.SubType_CD,
       :new.Successor_EID,
       :new.TaxYearEnd,
       :new.TerminationDate,
       SEQ_AUDITTRANSACTION.CurrVal, ''I'', v_LoginName, v_TransactionDate);
  ELSIF UPDATING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''U'', v_LoginName, v_TransactionDate, ''COMPANY'');
    INSERT INTO Company_Audit
      (
       old_AccountCode,
       old_AdministrationNumber,
       old_AgreementDate,
       old_AlternateName,
       old_AnnualMeetingDate,
       old_AnnualMeetingMonth,
       old_AnnualMeetingNotes_ID,
       old_ApprovedDate,
       old_ApprovedFirm,
       old_BeginDate,
       old_BillingMethod_CAT,
       old_BillingMethod_CD,
       old_BillsCustomer,
       old_BoardClasses,
       old_BooksLocation,
       old_ChangeBy,
       old_ChargeBackBeginDate,
       old_ChargeBackCode1,
       old_ChargeBackCode2,
       old_ChargeBackCode3,
       old_ChargeBackPct,
       old_Comments_ID,
       old_Company_ID,
       old_CompanyType_CAT,
       old_CompanyType_CD,
       old_CorpStatusDate,
       old_DateGuidelinesReturned,
       old_DirectorsAuthorized,
       old_DirectorsComments_ID,
       old_DirectorsMax,
       old_DirectorsMin,
       old_DirectorsQuorum,
       old_DismissalDate,
       old_Domicile_CAT,
       old_Domicile_CD,
       old_EndDate,
       old_ExternalEntityNumber,
	   old_eInvoicingVendorID,
       old_FemaleOwnership,
       old_FiscalYearEnd,
       old_GuidelinesReturned,
       old_HasEmployees,
       old_InternalNumber,
       old_IsBillingEntity,
       old_IsInsuranceCompany,
       old_LastChange,
       old_LastMeetingDate,
	   old_LHorganizationID,
       old_LineOfBusiness_CAT,
       old_LineOfBusiness_CD,
       old_LLCGovernedBy,
       old_MinorityFirm,
       old_PaymentMethod_CAT,
       old_PaymentMethod_CD,
       old_Purpose_ID,
       old_Region_CAT,
       old_Region_CD,
       old_Reject,
       old_SealLocation,
       old_SubType_CAT,
       old_SubType_CD,
       old_Successor_EID,
       old_TaxYearEnd,
       old_TerminationDate,
       new_AccountCode,
       new_AdministrationNumber,
       new_AgreementDate,
       new_AlternateName,
       new_AnnualMeetingDate,
       new_AnnualMeetingMonth,
       new_AnnualMeetingNotes_ID,
       new_ApprovedDate,
       new_ApprovedFirm,
       new_BeginDate,
       new_BillingMethod_CAT,
       new_BillingMethod_CD,
       new_BillsCustomer,
       new_BoardClasses,
       new_BooksLocation,
       new_ChangeBy,
       new_ChargeBackBeginDate,
       new_ChargeBackCode1,
       new_ChargeBackCode2,
       new_ChargeBackCode3,
       new_ChargeBackPct,
       new_Comments_ID,
       new_Company_ID,
       new_CompanyType_CAT,
       new_CompanyType_CD,
       new_CorpStatusDate,
       new_DateGuidelinesReturned,
       new_DirectorsAuthorized,
       new_DirectorsComments_ID,
       new_DirectorsMax,
       new_DirectorsMin,
       new_DirectorsQuorum,
       new_DismissalDate,
       new_Domicile_CAT,
       new_Domicile_CD,
       new_EndDate,
       new_ExternalEntityNumber,
	   new_eInvoicingVendorID,
       new_FemaleOwnership,
       new_FiscalYearEnd,
       new_GuidelinesReturned,
       new_HasEmployees,
       new_InternalNumber,
       new_IsBillingEntity,
       new_IsInsuranceCompany,
       new_LastChange,
       new_LastMeetingDate,
	   new_LHorganizationID,
       new_LineOfBusiness_CAT,
       new_LineOfBusiness_CD,
       new_LLCGovernedBy,
       new_MinorityFirm,
       new_PaymentMethod_CAT,
       new_PaymentMethod_CD,
       new_Purpose_ID,
       new_Region_CAT,
       new_Region_CD,
       new_Reject,
       new_SealLocation,
       new_SubType_CAT,
       new_SubType_CD,
       new_Successor_EID,
       new_TaxYearEnd,
       new_TerminationDate,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :old.AccountCode,
       :old.AdministrationNumber,
       :old.AgreementDate,
       :old.AlternateName,
       :old.AnnualMeetingDate,
       :old.AnnualMeetingMonth,
       :old.AnnualMeetingNotes_ID,
       :old.ApprovedDate,
       :old.ApprovedFirm,
       :old.BeginDate,
       :old.BillingMethod_CAT,
       :old.BillingMethod_CD,
       :old.BillsCustomer,
       :old.BoardClasses,
       :old.BooksLocation,
       :old.ChangeBy,
       :old.ChargeBackBeginDate,
       :old.ChargeBackCode1,
       :old.ChargeBackCode2,
       :old.ChargeBackCode3,
       :old.ChargeBackPct,
       :old.Comments_ID,
       :old.Company_ID,
       :old.CompanyType_CAT,
       :old.CompanyType_CD,
       :old.CorpStatusDate,
       :old.DateGuidelinesReturned,
       :old.DirectorsAuthorized,
       :old.DirectorsComments_ID,
       :old.DirectorsMax,
       :old.DirectorsMin,
       :old.DirectorsQuorum,
       :old.DismissalDate,
       :old.Domicile_CAT,
       :old.Domicile_CD,
       :old.EndDate,
       :old.ExternalEntityNumber,
	   :old.eInvoicingVendorID,
       :old.FemaleOwnership,
       :old.FiscalYearEnd,
       :old.GuidelinesReturned,
       :old.HasEmployees,
       :old.InternalNumber,
       :old.IsBillingEntity,
       :old.IsInsuranceCompany,
       :old.LastChange,
	   :old.LastMeetingDate,
	   :old.LHorganizationID,
       :old.LineOfBusiness_CAT,
       :old.LineOfBusiness_CD,
       :old.LLCGovernedBy,
       :old.MinorityFirm,
       :old.PaymentMethod_CAT,
       :old.PaymentMethod_CD,
       :old.Purpose_ID,
       :old.Region_CAT,
       :old.Region_CD,
       :old.Reject,
       :old.SealLocation,
       :old.SubType_CAT,
       :old.SubType_CD,
       :old.Successor_EID,
       :old.TaxYearEnd,
       :old.TerminationDate,
       :new.AccountCode,
       :new.AdministrationNumber,
       :new.AgreementDate,
       :new.AlternateName,
       :new.AnnualMeetingDate,
       :new.AnnualMeetingMonth,
       :new.AnnualMeetingNotes_ID,
       :new.ApprovedDate,
       :new.ApprovedFirm,
       :new.BeginDate,
       :new.BillingMethod_CAT,
       :new.BillingMethod_CD,
       :new.BillsCustomer,
       :new.BoardClasses,
       :new.BooksLocation,
       :new.ChangeBy,
       :new.ChargeBackBeginDate,
       :new.ChargeBackCode1,
       :new.ChargeBackCode2,
       :new.ChargeBackCode3,
       :new.ChargeBackPct,
       :new.Comments_ID,
       :new.Company_ID,
       :new.CompanyType_CAT,
       :new.CompanyType_CD,
       :new.CorpStatusDate,
       :new.DateGuidelinesReturned,
       :new.DirectorsAuthorized,
       :new.DirectorsComments_ID,
       :new.DirectorsMax,
       :new.DirectorsMin,
       :new.DirectorsQuorum,
       :new.DismissalDate,
       :new.Domicile_CAT,
       :new.Domicile_CD,
       :new.EndDate,
       :new.ExternalEntityNumber,
	   :new.eInvoicingVendorID,
       :new.FemaleOwnership,
       :new.FiscalYearEnd,
       :new.GuidelinesReturned,
       :new.HasEmployees,
       :new.InternalNumber,
       :new.IsBillingEntity,
       :new.IsInsuranceCompany,
       :new.LastChange,
       :new.LastMeetingDate,
	   :new.LHorganizationID,
       :new.LineOfBusiness_CAT,
       :new.LineOfBusiness_CD,
       :new.LLCGovernedBy,
       :new.MinorityFirm,
       :new.PaymentMethod_CAT,
       :new.PaymentMethod_CD,
       :new.Purpose_ID,
       :new.Region_CAT,
       :new.Region_CD,
       :new.Reject,
       :new.SealLocation,
       :new.SubType_CAT,
       :new.SubType_CD,
       :new.Successor_EID,
       :new.TaxYearEnd,
       :new.TerminationDate,
       SEQ_AUDITTRANSACTION.CurrVal, ''U'', v_LoginName, v_TransactionDate);
  ELSIF DELETING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''D'', v_LoginName, v_TransactionDate, ''COMPANY'');
    INSERT INTO Company_Audit
      (
       old_AccountCode,
       old_AdministrationNumber,
       old_AgreementDate,
       old_AlternateName,
       old_AnnualMeetingDate,
       old_AnnualMeetingMonth,
       old_AnnualMeetingNotes_ID,
       old_ApprovedDate,
       old_ApprovedFirm,
       old_BeginDate,
       old_BillingMethod_CAT,
       old_BillingMethod_CD,
       old_BillsCustomer,
       old_BoardClasses,
       old_BooksLocation,
       old_ChangeBy,
       old_ChargeBackBeginDate,
       old_ChargeBackCode1,
       old_ChargeBackCode2,
       old_ChargeBackCode3,
       old_ChargeBackPct,
       old_Comments_ID,
       old_Company_ID,
       old_CompanyType_CAT,
       old_CompanyType_CD,
       old_CorpStatusDate,
       old_DateGuidelinesReturned,
       old_DirectorsAuthorized,
       old_DirectorsComments_ID,
       old_DirectorsMax,
       old_DirectorsMin,
       old_DirectorsQuorum,
       old_DismissalDate,
       old_Domicile_CAT,
       old_Domicile_CD,
       old_EndDate,
       old_ExternalEntityNumber,
	   old_eInvoicingVendorID,
       old_FemaleOwnership,
       old_FiscalYearEnd,
       old_GuidelinesReturned,
       old_HasEmployees,
       old_InternalNumber,
       old_IsBillingEntity,
       old_IsInsuranceCompany,
       old_LastChange,
       old_LastMeetingDate,
	   old_LHorganizationID,
       old_LineOfBusiness_CAT,
       old_LineOfBusiness_CD,
       old_LLCGovernedBy,
       old_MinorityFirm,
       old_PaymentMethod_CAT,
       old_PaymentMethod_CD,
       old_Purpose_ID,
       old_Region_CAT,
       old_Region_CD,
       old_Reject,
       old_SealLocation,
       old_SubType_CAT,
       old_SubType_CD,
       old_Successor_EID,
       old_TaxYearEnd,
       old_TerminationDate,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :old.AccountCode,
       :old.AdministrationNumber,
       :old.AgreementDate,
       :old.AlternateName,
       :old.AnnualMeetingDate,
       :old.AnnualMeetingMonth,
       :old.AnnualMeetingNotes_ID,
       :old.ApprovedDate,
       :old.ApprovedFirm,
       :old.BeginDate,
       :old.BillingMethod_CAT,
       :old.BillingMethod_CD,
       :old.BillsCustomer,
       :old.BoardClasses,
       :old.BooksLocation,
       :old.ChangeBy,
       :old.ChargeBackBeginDate,
       :old.ChargeBackCode1,
       :old.ChargeBackCode2,
       :old.ChargeBackCode3,
       :old.ChargeBackPct,
       :old.Comments_ID,
       :old.Company_ID,
       :old.CompanyType_CAT,
       :old.CompanyType_CD,
       :old.CorpStatusDate,
       :old.DateGuidelinesReturned,
       :old.DirectorsAuthorized,
       :old.DirectorsComments_ID,
       :old.DirectorsMax,
       :old.DirectorsMin,
       :old.DirectorsQuorum,
       :old.DismissalDate,
       :old.Domicile_CAT,
       :old.Domicile_CD,
       :old.EndDate,
       :old.ExternalEntityNumber,
	   :old.eInvoicingVendorID,
       :old.FemaleOwnership,
       :old.FiscalYearEnd,
       :old.GuidelinesReturned,
       :old.HasEmployees,
       :old.InternalNumber,
       :old.IsBillingEntity,
       :old.IsInsuranceCompany,
       :old.LastChange,
       :old.LastMeetingDate,
	   :old.LHorganizationID,
       :old.LineOfBusiness_CAT,
       :old.LineOfBusiness_CD,
       :old.LLCGovernedBy,
       :old.MinorityFirm,
       :old.PaymentMethod_CAT,
       :old.PaymentMethod_CD,
       :old.Purpose_ID,
       :old.Region_CAT,
       :old.Region_CD,
       :old.Reject,
       :old.SealLocation,
       :old.SubType_CAT,
       :old.SubType_CD,
       :old.Successor_EID,
       :old.TaxYearEnd,
       :old.TerminationDate,
       SEQ_AUDITTRANSACTION.CurrVal, ''D'', v_LoginName, v_TransactionDate);
  ELSE
    NULL;
  END IF;
END;';
	END;
  ELSE
    NULL;
  END IF;
END;
/

---Audit_Matter trigger 
DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTrigger
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Matter';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
	  '
	  CREATE OR REPLACE TRIGGER AUDIT_MATTER
  BEFORE INSERT OR DELETE OR UPDATE ON MATTER
  FOR EACH ROW
DECLARE
  v_UserSID            NUMBER(10,0);
  v_AuditUserSID       NUMBER(10,0);
  v_LoginDate          DATE;
  v_LoginName          VARCHAR2(20);
  v_TransactionDate    DATE;

  CURSOR c_AuditUserSID IS
    SELECT UserSID, LoginDate
      FROM AuditUserSID;

BEGIN
  SELECT SYSDATE
    INTO v_TransactionDate
    FROM DUAL;

  SELECT DISTINCT(SID)
    INTO v_UserSID
    FROM V$MYSTAT;

  OPEN c_AuditUserSID;
  LOOP
    FETCH c_AuditUserSID
      INTO v_AuditUserSID, v_LoginDate;
    EXIT WHEN c_AuditUserSID%NOTFOUND;

    IF v_UserSID = v_AuditUserSID and v_LoginDate > (SYSDATE-5/24/60) THEN
      SELECT LoginName
        INTO v_LoginName
        FROM AuditUserSID
        WHERE UserSID = v_UserSID;
      ELSE
        NULL;
    END IF;
  END LOOP;
  CLOSE c_AuditUserSID;

  IF v_LoginName IS NULL THEN
     v_LoginName := ''Unknown'';
    ELSE
      NULL;
  END IF;
  IF INSERTING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''I'', v_LoginName, v_TransactionDate, ''MATTER'');
    INSERT INTO Matter_Audit
      (
       new_AccrueCosts,
	   new_ActiveHolds,
	   new_BillAfterClose,
       new_Budgeted,
       new_ChangeBy,
       new_CloseDate,
       new_CloseDate_ID,
	   new_CollaboratiSync,
       new_Comments_ID,
       new_Country_CAT,
       new_Country_CD,
       new_CreatedDate,
	   new_eInvoicingMatterID,
       new_Exported,
       new_FileNumber,
       new_Insured,
       new_LastChange,
       new_Law_CAT,
       new_Law_CD,
       new_LegalSection_CAT,
       new_LegalSection_CD,
	   new_LHMatterID,
       new_Litigated,	   
       new_LogicalGroup_ID,
       new_LongMatterName,
       new_LongMatterName_ID,
       new_Matter_CAT,
       new_Matter_CD,
       new_MatterName,
       new_MatterNumber,
       new_MatterNumber_ID,
       new_MatterStatus_CAT,
       new_MatterStatus_CD,
	   new_NeedSync,
       new_OpenDate,
       new_OpenDate_ID,
       new_Priority_CAT,
       new_Priority_CD,
       new_PrivateChangeBy_ID,
       new_PrivateChangeDate,
       new_PrivateMatter,
       new_ProductService_CAT,
       new_ProductService_CD,
       new_Region_CAT,
       new_Region_CD,
       new_ReOpenDate,
       new_ReOpenDate_ID,
       new_State_CAT,
       new_State_CD,
       new_SubLaw_CAT,
       new_SubLaw_CD,
       new_SubProductService_CAT,
       new_SubProductService_CD,
       new_TargetDate,
       new_TargetDate_ID,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
	   :new.AccrueCosts,
	   :new.ActiveHolds,
       :new.BillAfterClose,
       :new.Budgeted,
       :new.ChangeBy,
       :new.CloseDate,
       :new.CloseDate_ID,
	   :new.CollaboratiSync,
       :new.Comments_ID,
       :new.Country_CAT,
       :new.Country_CD,
       :new.CreatedDate,
	   :new.eInvoicingMatterID,
       :new.Exported,
       :new.FileNumber,
       :new.Insured,
       :new.LastChange,
       :new.Law_CAT,
       :new.Law_CD,
       :new.LegalSection_CAT,
       :new.LegalSection_CD,
	   :new.LHMatterID,
       :new.Litigated,
       :new.LogicalGroup_ID,
       :new.LongMatterName,
       :new.LongMatterName_ID,
       :new.Matter_CAT,
       :new.Matter_CD,
       :new.MatterName,
       :new.MatterNumber,
       :new.MatterNumber_ID,
       :new.MatterStatus_CAT,
       :new.MatterStatus_CD,
	   :new.NeedSync,
       :new.OpenDate,
       :new.OpenDate_ID,
       :new.Priority_CAT,
       :new.Priority_CD,
       :new.PrivateChangeBy_ID,
       :new.PrivateChangeDate,
       :new.PrivateMatter,
       :new.ProductService_CAT,
       :new.ProductService_CD,
       :new.Region_CAT,
       :new.Region_CD,
       :new.ReOpenDate,
       :new.ReOpenDate_ID,
       :new.State_CAT,
       :new.State_CD,
       :new.SubLaw_CAT,
       :new.SubLaw_CD,
       :new.SubProductService_CAT,
       :new.SubProductService_CD,
       :new.TargetDate,
       :new.TargetDate_ID,
       SEQ_AUDITTRANSACTION.CurrVal, ''I'', v_LoginName, v_TransactionDate);
  ELSIF UPDATING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''U'', v_LoginName, v_TransactionDate, ''MATTER'');
    INSERT INTO Matter_Audit
      (
       old_AccrueCosts,
	   old_ActiveHolds,
	   old_BillAfterClose,
       old_Budgeted,
       old_ChangeBy,
       old_CloseDate,
       old_CloseDate_ID,
	   old_CollaboratiSync,
       old_Comments_ID,
       old_Country_CAT,
       old_Country_CD,
       old_CreatedDate,
	   old_eInvoicingMatterID,
       old_Exported,
       old_FileNumber,
       old_Insured,
       old_LastChange,
       old_Law_CAT,
       old_Law_CD,
       old_LegalSection_CAT,
       old_LegalSection_CD,
	   old_LHMatterID,
       old_Litigated,
       old_LogicalGroup_ID,
       old_LongMatterName,
       old_LongMatterName_ID,
       old_Matter_CAT,
       old_Matter_CD,
       old_MatterName,
       old_MatterNumber,
       old_MatterNumber_ID,
       old_MatterStatus_CAT,
       old_MatterStatus_CD,
	   old_NeedSync,
       old_OpenDate,
       old_OpenDate_ID,
       old_Priority_CAT,
       old_Priority_CD,
       old_PrivateChangeBy_ID,
       old_PrivateChangeDate,
       old_PrivateMatter,
       old_ProductService_CAT,
       old_ProductService_CD,
       old_Region_CAT,
       old_Region_CD,
       old_ReOpenDate,
       old_ReOpenDate_ID,
       old_State_CAT,
       old_State_CD,
       old_SubLaw_CAT,
       old_SubLaw_CD,
       old_SubProductService_CAT,
       old_SubProductService_CD,
       old_TargetDate,
       old_TargetDate_ID,
       new_AccrueCosts,
	   new_ActiveHolds,
	   new_BillAfterClose,
       new_Budgeted,
       new_ChangeBy,
       new_CloseDate,
       new_CloseDate_ID,
	   new_CollaboratiSync,
       new_Comments_ID,
       new_Country_CAT,
       new_Country_CD,
       new_CreatedDate,
	   new_eInvoicingMatterID,
       new_Exported,
       new_FileNumber,
       new_Insured,
       new_LastChange,
       new_Law_CAT,
       new_Law_CD,
       new_LegalSection_CAT,
       new_LegalSection_CD,
	   new_LHMatterID,
       new_Litigated,
       new_LogicalGroup_ID,
       new_LongMatterName,
       new_LongMatterName_ID,
       new_Matter_CAT,
       new_Matter_CD,
       new_MatterName,
       new_MatterNumber,
       new_MatterNumber_ID,
       new_MatterStatus_CAT,
       new_MatterStatus_CD,
	   new_NeedSync,
       new_OpenDate,
       new_OpenDate_ID,
       new_Priority_CAT,
       new_Priority_CD,
       new_PrivateChangeBy_ID,
       new_PrivateChangeDate,
       new_PrivateMatter,
       new_ProductService_CAT,
       new_ProductService_CD,
       new_Region_CAT,
       new_Region_CD,
       new_ReOpenDate,
       new_ReOpenDate_ID,
       new_State_CAT,
       new_State_CD,
       new_SubLaw_CAT,
       new_SubLaw_CD,
       new_SubProductService_CAT,
       new_SubProductService_CD,
       new_TargetDate,
       new_TargetDate_ID,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :old.AccrueCosts,
	   :old.ActiveHolds,
	   :old.BillAfterClose,
       :old.Budgeted,
       :old.ChangeBy,
       :old.CloseDate,
       :old.CloseDate_ID,
	   :old.CollaboratiSync,
       :old.Comments_ID,
       :old.Country_CAT,
       :old.Country_CD,
       :old.CreatedDate,
	   :old.eInvoicingMatterID,
       :old.Exported,
       :old.FileNumber,
       :old.Insured,
       :old.LastChange,
       :old.Law_CAT,
       :old.Law_CD,
       :old.LegalSection_CAT,
       :old.LegalSection_CD,
	   :old.LHMatterID,
       :old.Litigated,
       :old.LogicalGroup_ID,
       :old.LongMatterName,
       :old.LongMatterName_ID,
       :old.Matter_CAT,
       :old.Matter_CD,
       :old.MatterName,
       :old.MatterNumber,
       :old.MatterNumber_ID,
       :old.MatterStatus_CAT,
       :old.MatterStatus_CD,
	   :old.NeedSync,
       :old.OpenDate,
       :old.OpenDate_ID,
       :old.Priority_CAT,
       :old.Priority_CD,
       :old.PrivateChangeBy_ID,
       :old.PrivateChangeDate,
       :old.PrivateMatter,
       :old.ProductService_CAT,
       :old.ProductService_CD,
       :old.Region_CAT,
       :old.Region_CD,
       :old.ReOpenDate,
       :old.ReOpenDate_ID,
       :old.State_CAT,
       :old.State_CD,
       :old.SubLaw_CAT,
       :old.SubLaw_CD,
       :old.SubProductService_CAT,
       :old.SubProductService_CD,
       :old.TargetDate,
       :old.TargetDate_ID,
       :new.AccrueCosts,
	   :new.ActiveHolds,
	   :new.BillAfterClose,
       :new.Budgeted,
       :new.ChangeBy,
       :new.CloseDate,
       :new.CloseDate_ID,
	   :new.CollaboratiSync,
       :new.Comments_ID,
       :new.Country_CAT,
       :new.Country_CD,
       :new.CreatedDate,
	   :new.eInvoicingMatterID,
       :new.Exported,
       :new.FileNumber,
       :new.Insured,
       :new.LastChange,
       :new.Law_CAT,
       :new.Law_CD,
       :new.LegalSection_CAT,
       :new.LegalSection_CD,
	   :new.LHMatterID,
       :new.Litigated,
       :new.LogicalGroup_ID,
       :new.LongMatterName,
       :new.LongMatterName_ID,
       :new.Matter_CAT,
       :new.Matter_CD,
       :new.MatterName,
       :new.MatterNumber,
       :new.MatterNumber_ID,
       :new.MatterStatus_CAT,
       :new.MatterStatus_CD,
	   :new.NeedSync,
       :new.OpenDate,
       :new.OpenDate_ID,
       :new.Priority_CAT,
       :new.Priority_CD,
       :new.PrivateChangeBy_ID,
       :new.PrivateChangeDate,
       :new.PrivateMatter,
       :new.ProductService_CAT,
       :new.ProductService_CD,
       :new.Region_CAT,
       :new.Region_CD,
       :new.ReOpenDate,
       :new.ReOpenDate_ID,
       :new.State_CAT,
       :new.State_CD,
       :new.SubLaw_CAT,
       :new.SubLaw_CD,
       :new.SubProductService_CAT,
       :new.SubProductService_CD,
       :new.TargetDate,
       :new.TargetDate_ID,
       SEQ_AUDITTRANSACTION.CurrVal, ''U'', v_LoginName, v_TransactionDate);
  ELSIF DELETING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''D'', v_LoginName, v_TransactionDate, ''MATTER'');
    INSERT INTO Matter_Audit
      (
       old_AccrueCosts,
	   old_ActiveHolds,
	   old_BillAfterClose,
       old_Budgeted,
       old_ChangeBy,
       old_CloseDate,
       old_CloseDate_ID,
	   old_CollaboratiSync,
       old_Comments_ID,
       old_Country_CAT,
       old_Country_CD,
       old_CreatedDate,
	   old_eInvoicingMatterID,
       old_Exported,
       old_FileNumber,
       old_Insured,
       old_LastChange,
       old_Law_CAT,
       old_Law_CD,
       old_LegalSection_CAT,
       old_LegalSection_CD,
	   old_LHMatterID,
       old_Litigated,
       old_LogicalGroup_ID,
       old_LongMatterName,
       old_LongMatterName_ID,
       old_Matter_CAT,
       old_Matter_CD,
       old_MatterName,
       old_MatterNumber,
       old_MatterNumber_ID,
       old_MatterStatus_CAT,
       old_MatterStatus_CD,
	   old_NeedSync,
       old_OpenDate,
       old_OpenDate_ID,
       old_Priority_CAT,
       old_Priority_CD,
       old_PrivateChangeBy_ID,
       old_PrivateChangeDate,
       old_PrivateMatter,
       old_ProductService_CAT,
       old_ProductService_CD,
       old_Region_CAT,
       old_Region_CD,
       old_ReOpenDate,
       old_ReOpenDate_ID,
       old_State_CAT,
       old_State_CD,
       old_SubLaw_CAT,
       old_SubLaw_CD,
       old_SubProductService_CAT,
       old_SubProductService_CD,
       old_TargetDate,
       old_TargetDate_ID,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :old.AccrueCosts,
	   :old.ActiveHolds,
	   :old.BillAfterClose,
       :old.Budgeted,
       :old.ChangeBy,
       :old.CloseDate,
       :old.CloseDate_ID,
	   :old.CollaboratiSync,
       :old.Comments_ID,
       :old.Country_CAT,
       :old.Country_CD,
       :old.CreatedDate,
	   :old.eInvoicingMatterID,
       :old.Exported,
       :old.FileNumber,
       :old.Insured,
       :old.LastChange,
       :old.Law_CAT,
       :old.Law_CD,
       :old.LegalSection_CAT,
       :old.LegalSection_CD,
	   :old.LHMatterID,
       :old.Litigated,
       :old.LogicalGroup_ID,
       :old.LongMatterName,
       :old.LongMatterName_ID,
       :old.Matter_CAT,
       :old.Matter_CD,
       :old.MatterName,
       :old.MatterNumber,
       :old.MatterNumber_ID,
       :old.MatterStatus_CAT,
       :old.MatterStatus_CD,
	   :old.NeedSync,
       :old.OpenDate,
       :old.OpenDate_ID,
       :old.Priority_CAT,
       :old.Priority_CD,
       :old.PrivateChangeBy_ID,
       :old.PrivateChangeDate,
       :old.PrivateMatter,
       :old.ProductService_CAT,
       :old.ProductService_CD,
       :old.Region_CAT,
       :old.Region_CD,
       :old.ReOpenDate,
       :old.ReOpenDate_ID,
       :old.State_CAT,
       :old.State_CD,
       :old.SubLaw_CAT,
       :old.SubLaw_CD,
       :old.SubProductService_CAT,
       :old.SubProductService_CD,
       :old.TargetDate,
       :old.TargetDate_ID,
       SEQ_AUDITTRANSACTION.CurrVal, ''D'', v_LoginName, v_TransactionDate);
  ELSE
    NULL;
  END IF;
END;';
    END;
  ELSE
    NULL;
  END IF;
END;
/

--PERSON
DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTrigger
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Person';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
	  '
	  CREATE OR REPLACE TRIGGER AUDIT_PERSON
  BEFORE INSERT OR DELETE OR UPDATE ON PERSON
  FOR EACH ROW
DECLARE
  v_UserSID            NUMBER(10,0);
  v_AuditUserSID       NUMBER(10,0);
  v_LoginDate          DATE;
  v_LoginName          VARCHAR2(20);
  v_TransactionDate    DATE;

  CURSOR c_AuditUserSID IS
    SELECT UserSID, LoginDate
      FROM AuditUserSID;

BEGIN
  SELECT SYSDATE
    INTO v_TransactionDate
    FROM DUAL;

  SELECT DISTINCT(SID)
    INTO v_UserSID
    FROM V$MYSTAT;

  OPEN c_AuditUserSID;
  LOOP
    FETCH c_AuditUserSID
      INTO v_AuditUserSID, v_LoginDate;
    EXIT WHEN c_AuditUserSID%NOTFOUND;

    IF v_UserSID = v_AuditUserSID and v_LoginDate > (SYSDATE-5/24/60) THEN
      SELECT LoginName
        INTO v_LoginName
        FROM AuditUserSID
        WHERE UserSID = v_UserSID;
      ELSE
        NULL;
    END IF;
  END LOOP;
  CLOSE c_AuditUserSID;

  IF v_LoginName IS NULL THEN
     v_LoginName := ''Unknown'';
    ELSE
      NULL;
  END IF;
  IF INSERTING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''I'', v_LoginName, v_TransactionDate, ''PERSON'');
    INSERT INTO Person_Audit
      (
       new_AdministrationNumber,
       new_BirthDate,
       new_BirthPlace,
       new_ChangeBy,
       new_CitizenJurisdiction_ID,
       new_Comments_ID,
       new_DailyMaximumHours,
       new_DailyMinumumHours,
       new_DeathDate,
       new_DriversLicense,
       new_DriversLicenseJuris_ID,
       new_Employee,
       new_EmployeeEndDate,
       new_EmployeeStartDate,
       new_EthnicClassification_CAT,
       new_EthnicClassification_CD,
       new_FirstName,
       new_Gender,
       new_LastChange,
       new_LastName,
	   new_LHLegalHoldStaffID,
       new_Middle,
       new_Nickname,
       new_PassportNumber,
       new_Person_ID,
       new_Salutation,
       new_Secretary,
       new_SecurityLevel,
       new_Spouse,
       new_SpouseSSN,
       new_StartOfWeek,
       new_Suffix,
       new_Timekeeper,
       new_AssociatedTimekeeperID,
       new_TimekeeperSync,
	   new_eInvoicingTimekeeperID,
	   new_eInvoicingAuthorized,
	   new_Initials,
       new_TimekeeperComments_ID,
       new_WeeklyMaximumHours,
       new_WeeklyMinimumHours,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :new.AdministrationNumber,
       :new.BirthDate,
       :new.BirthPlace,
       :new.ChangeBy,
       :new.CitizenJurisdiction_ID,
       :new.Comments_ID,
       :new.DailyMaximumHours,
       :new.DailyMinumumHours,
       :new.DeathDate,
       :new.DriversLicense,
       :new.DriversLicenseJurisdiction_ID,
       :new.Employee,
       :new.EmployeeEndDate,
       :new.EmployeeStartDate,
       :new.EthnicClassification_CAT,
       :new.EthnicClassification_CD,
       :new.FirstName,
       :new.Gender,
       :new.LastChange,
       :new.LastName,
	   :new.LHLegalHoldStaffID,
       :new.Middle,
       :new.Nickname,
       :new.PassportNumber,
       :new.Person_ID,
       :new.Salutation,
       :new.Secretary,
       :new.SecurityLevel,
       :new.Spouse,
       :new.SpouseSSN,
       :new.StartOfWeek,
       :new.Suffix,
       :new.Timekeeper,
       :new.AssociatedTimekeeperID,
       :new.TimekeeperSync,
	   :new.eInvoicingTimekeeperID,
	   :new.eInvoicingAuthorized,
	   :new.Initials,
       :new.TimekeeperComments_ID,
       :new.WeeklyMaximumHours,
       :new.WeeklyMinimumHours,
       SEQ_AUDITTRANSACTION.CurrVal, ''I'', v_LoginName, v_TransactionDate);
  ELSIF UPDATING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''U'', v_LoginName, v_TransactionDate, ''PERSON'');
    INSERT INTO Person_Audit
      (
       old_AdministrationNumber,
       old_BirthDate,
       old_BirthPlace,
       old_ChangeBy,
       old_CitizenJurisdiction_ID,
       old_Comments_ID,
       old_DailyMaximumHours,
       old_DailyMinumumHours,
       old_DeathDate,
       old_DriversLicense,
       old_DriversLicenseJuris_ID,
       old_Employee,
       old_EmployeeEndDate,
       old_EmployeeStartDate,
       old_EthnicClassification_CAT,
       old_EthnicClassification_CD,
       old_FirstName,
       old_Gender,
       old_LastChange,
       old_LastName,
	   old_LHLegalHoldStaffID,
       old_Middle,
       old_Nickname,
       old_PassportNumber,
       old_Person_ID,
       old_Salutation,
       old_Secretary,
       old_SecurityLevel,
       old_Spouse,
       old_SpouseSSN,
       old_StartOfWeek,
       old_Suffix,
       old_Timekeeper,
       old_AssociatedTimekeeperID,
       old_TimekeeperSync,
	   old_eInvoicingTimekeeperID,
	   old_eInvoicingAuthorized,
	   old_Initials,
       old_TimekeeperComments_ID,
       old_WeeklyMaximumHours,
       old_WeeklyMinimumHours,
       new_AdministrationNumber,
       new_BirthDate,
       new_BirthPlace,
       new_ChangeBy,
       new_CitizenJurisdiction_ID,
       new_Comments_ID,
       new_DailyMaximumHours,
       new_DailyMinumumHours,
       new_DeathDate,
       new_DriversLicense,
       new_DriversLicenseJuris_ID,
       new_Employee,
       new_EmployeeEndDate,
       new_EmployeeStartDate,
       new_EthnicClassification_CAT,
       new_EthnicClassification_CD,
       new_FirstName,
       new_Gender,
       new_LastChange,
       new_LastName,
	   new_LHLegalHoldStaffID,
       new_Middle,
       new_Nickname,
       new_PassportNumber,
       new_Person_ID,
       new_Salutation,
       new_Secretary,
       new_SecurityLevel,
       new_Spouse,
       new_SpouseSSN,
       new_StartOfWeek,
       new_Suffix,
       new_Timekeeper,
       new_AssociatedTimekeeperID,
       new_TimekeeperSync,
	   new_eInvoicingTimekeeperID,
	   new_eInvoicingAuthorized,
	   new_Initials,
       new_TimekeeperComments_ID,
       new_WeeklyMaximumHours,
       new_WeeklyMinimumHours,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :old.AdministrationNumber,
       :old.BirthDate,
       :old.BirthPlace,
       :old.ChangeBy,
       :old.CitizenJurisdiction_ID,
       :old.Comments_ID,
       :old.DailyMaximumHours,
       :old.DailyMinumumHours,
       :old.DeathDate,
       :old.DriversLicense,
       :old.DriversLicenseJurisdiction_ID,
       :old.Employee,
       :old.EmployeeEndDate,
       :old.EmployeeStartDate,
       :old.EthnicClassification_CAT,
       :old.EthnicClassification_CD,
       :old.FirstName,
       :old.Gender,
       :old.LastChange,
       :old.LastName,
	   :old.LHLegalHoldStaffID,
       :old.Middle,
       :old.Nickname,
       :old.PassportNumber,
       :old.Person_ID,
       :old.Salutation,
       :old.Secretary,
       :old.SecurityLevel,
       :old.Spouse,
       :old.SpouseSSN,
       :old.StartOfWeek,
       :old.Suffix,
       :old.Timekeeper,
       :old.AssociatedTimekeeperID,
       :old.TimekeeperSync,
	   :old.eInvoicingTimekeeperID,
	   :old.eInvoicingAuthorized,
	   :old.Initials,
       :old.TimekeeperComments_ID,
       :old.WeeklyMaximumHours,
       :old.WeeklyMinimumHours,
       :new.AdministrationNumber,
       :new.BirthDate,
       :new.BirthPlace,
       :new.ChangeBy,
       :new.CitizenJurisdiction_ID,
       :new.Comments_ID,
       :new.DailyMaximumHours,
       :new.DailyMinumumHours,
       :new.DeathDate,
       :new.DriversLicense,
       :new.DriversLicenseJurisdiction_ID,
       :new.Employee,
       :new.EmployeeEndDate,
       :new.EmployeeStartDate,
       :new.EthnicClassification_CAT,
       :new.EthnicClassification_CD,
       :new.FirstName,
       :new.Gender,
       :new.LastChange,
       :new.LastName,
	   :new.LHLegalHoldStaffID,
       :new.Middle,
       :new.Nickname,
       :new.PassportNumber,
       :new.Person_ID,
       :new.Salutation,
       :new.Secretary,
       :new.SecurityLevel,
       :new.Spouse,
       :new.SpouseSSN,
       :new.StartOfWeek,
       :new.Suffix,
       :new.Timekeeper,
       :new.AssociatedTimekeeperID,
       :new.TimekeeperSync,
	   :new.eInvoicingTimekeeperID,
	   :new.eInvoicingAuthorized,
	   :new.Initials,
       :new.TimekeeperComments_ID,
       :new.WeeklyMaximumHours,
       :new.WeeklyMinimumHours,
       SEQ_AUDITTRANSACTION.CurrVal, ''U'', v_LoginName, v_TransactionDate);
  ELSIF DELETING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''D'', v_LoginName, v_TransactionDate, ''PERSON'');
    INSERT INTO Person_Audit
      (
       old_AdministrationNumber,
       old_BirthDate,
       old_BirthPlace,
       old_ChangeBy,
       old_CitizenJurisdiction_ID,
       old_Comments_ID,
       old_DailyMaximumHours,
       old_DailyMinumumHours,
       old_DeathDate,
       old_DriversLicense,
       old_DriversLicenseJuris_ID,
       old_Employee,
       old_EmployeeEndDate,
       old_EmployeeStartDate,
       old_EthnicClassification_CAT,
       old_EthnicClassification_CD,
       old_FirstName,
       old_Gender,
       old_LastChange,
       old_LastName,
	   old_LHLegalHoldStaffID,
       old_Middle,
       old_Nickname,
       old_PassportNumber,
       old_Person_ID,
       old_Salutation,
       old_Secretary,
       old_SecurityLevel,
       old_Spouse,
       old_SpouseSSN,
       old_StartOfWeek,
       old_Suffix,
       old_Timekeeper,
       old_AssociatedTimekeeperID,
       old_TimekeeperSync,
	   old_eInvoicingTimekeeperID,
	   old_eInvoicingAuthorized,
	   old_Initials,
       old_TimekeeperComments_ID,
       old_WeeklyMaximumHours,
       old_WeeklyMinimumHours,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :old.AdministrationNumber,
       :old.BirthDate,
       :old.BirthPlace,
       :old.ChangeBy,
       :old.CitizenJurisdiction_ID,
       :old.Comments_ID,
       :old.DailyMaximumHours,
       :old.DailyMinumumHours,
       :old.DeathDate,
       :old.DriversLicense,
       :old.DriversLicenseJurisdiction_ID,
       :old.Employee,
       :old.EmployeeEndDate,
       :old.EmployeeStartDate,
       :old.EthnicClassification_CAT,
       :old.EthnicClassification_CD,
       :old.FirstName,
       :old.Gender,
       :old.LastChange,
       :old.LastName,
	   :old.LHLegalHoldStaffID,
       :old.Middle,
       :old.Nickname,
       :old.PassportNumber,
       :old.Person_ID,
       :old.Salutation,
       :old.Secretary,
       :old.SecurityLevel,
       :old.Spouse,
       :old.SpouseSSN,
       :old.StartOfWeek,
       :old.Suffix,
       :old.Timekeeper,
       :old.AssociatedTimekeeperID,
       :old.TimekeeperSync,
	   :old.eInvoicingTimekeeperID,
	   :old.eInvoicingAuthorized,
	   :old.Initials,
       :old.TimekeeperComments_ID,
       :old.WeeklyMaximumHours,
       :old.WeeklyMinimumHours,
       SEQ_AUDITTRANSACTION.CurrVal, ''D'', v_LoginName, v_TransactionDate);
  ELSE
    NULL;
  END IF;
END;';
  	END;
  ELSE
    NULL;
  END IF;
END;
/
-- End Audit trigger changes

-- Begin grant permissions (audit tables)

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Company';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE 'grant select on Company_Audit to <LOGIN>';
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Matter';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE 'grant select on Matter_Audit to <LOGIN>';
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Person';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE 'grant select on Person_Audit to <LOGIN>';
    END;
  ELSE
    NULL;
  END IF;
END;
/

-- End grant permissions (audit tables)


---------------- End Auditing Section ----------------

-----------------BEGIN PROCEDURE SECTION-------------------------------

---BEGIN create procedure MLHGetPlayerInfo
DECLARE
v_exist NUMBER(10,0):=0;
BEGIN
  SELECT Count(*) into v_exist FROM user_procedures where object_name='MLHGETPLAYERINFO';
  IF v_exist > 0 THEN
   EXECUTE IMMEDIATE 'drop procedure MLHGETPLAYERINFO';
  END IF;
END;
/

create or replace 
procedure MLHGetPlayerInfo (v_matterID IN number,rf_cur OUT SYS_REFCURSOR)
   as
 begin
   open rf_cur for
    	Select p.Person_ID, p.FirstName, p.LastName, p.Suffix, 

		 p.LHlegalholdStaffID as matterStaffID,
		 
		 e.Status_CD as personStatus, 

		 mp.Role_CD, lcs.SyncValue as playerRoleUID,

		 mp.MatterPlayer_ID,		 

		 mp.StartDate,mp.EndDate,m.LHMatterID

	from Person  p
	
	inner join Entity e on e.Entity_EID = p.Person_ID

	inner join MatterPlayer mp on p.Person_ID = mp.Entity_EID

	inner join Matter m on m.MatterNumber_ID = mp.MatterNumber_ID

	inner join LookupCode lc on lc.CodeName = mp.Role_CD

	inner join LookupCodeSync lcs on lcs.LookupCode_ID = lc.LookupCode_ID

	where mp.MatterNumber_ID = v_matterID;  
end;
/
---ENDcreate procedure MLHGetPlayerInfo

-----------------END PROCEDURE SECTION---------------------------------

-- Begin Legalhold views
begin
  execute immediate 'drop view VLH_MatterTypes_Status';
  exception
    when others then null;
end;
/

create or replace view VLH_MatterTypes_Status
as 
/************************************************************************************************************************
Definition: This view returns the matterplayers status that have been syncing to Legalhold
************************************************************************************************************************/
    select lc.LookupCode_ID, lc.CodeName, lcs.Status

    from LookupCode lc

    left join LookupCodeSync lcs

    on lcs.LookupCode_ID = lc.LookupCode_ID

    where lc.LookupCodeCategory_ID = 38;
/

begin
  execute immediate 'drop view VLH_RolesCodes_Status';
  exception
    when others then null;
end;
/

create or replace view VLH_RolesCodes_Status
as 
/************************************************************************************************************************
Definition: This view returns the RoleCodes status that have been syncing to Legalhold
************************************************************************************************************************/
     select lc.LookupCode_ID, lc.CodeName, lc2.CodeName as PlayerType, lcs.Status
	 from LookupCode lc 
	 left join LookupCodeSync lcs
	 on lcs.LookupCode_ID=lc.LookupCode_ID 
	 left join LookupCodeSubCategory lcscat
	 on lcscat.SubCode_ID = lc.LookupCode_ID
	 left join LookupCode lc2 
	 on lc2.LookupCode_ID=lcscat.ParentCode_ID 
	 where lc.LookupCodeCategory_ID = 60;
/

-- End Legalhold views

--BEGIN NEW TABLES
DECLARE
  v_ObjectCount         NUMBER(1);
BEGIN
  SELECT COUNT(*)
    INTO v_ObjectCount
    FROM User_Tables
    WHERE Table_Name = 'LH_LEGALHOLDMATTER';

  IF v_ObjectCount = 1 THEN
	 EXECUTE IMMEDIATE 'DROP TABLE LH_LEGALHOLDMATTER';
	 COMMIT;
    ELSE
      NULL;
  END IF;
END;
/

create table LH_LegalHoldMatter  (
   LH_LegalHoldMatter_ID	 NUMBER(10,0)                    not null,
   MatterNumber_ID		     NUMBER(10,0),
   LHHoldKey	             VARCHAR2(50),
   CreatedDate		         DATE,
   CreatedBy 		         VARCHAR2(20 BYTE),
   LastChange		         DATE,
   ChangeBy			         VARCHAR2(20 BYTE),
   constraint PK_LH_LEGALHOLDMATTER primary key (LH_LegalHoldMatter_ID)
	using index tablespace <INDEX_TABLESPACE>
);

create index IDX_LHM_MATTERNUMBER_ID on LH_LegalHoldMatter (
MatterNumber_ID asc
)
tablespace <INDEX_TABLESPACE>;
/

alter table LH_LegalHoldMatter
	add constraint FK_LH_LEGAL_REF_3143_MATTER foreign key (MatterNumber_ID)
		references Matter (MatterNumber_ID);
	/
		
DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Invoice';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
'
create table LH_LegalHoldMatter_Audit
(
	old_LH_LegalHoldMatter_ID	 NUMBER(10,0)	 		null,
	new_LH_LegalHoldMatter_ID	 NUMBER(10,0)	 		null,
	old_MatterNumber_ID			 NUMBER(10,0)			null,
	new_MatterNumber_ID			 NUMBER(10,0)			null,
	old_LHHoldKey				 VARCHAR2(50) 			null,
	new_LHHoldKey				 VARCHAR2(50) 			null,
	old_CreatedDate				 DATE					null,
	new_CreatedDate				 DATE					null,
	old_CreatedBy				 VARCHAR2(20)			null,
	new_CreatedBy				 VARCHAR2(20)			null,
	old_LastChange				 DATE					null,
	new_LastChange				 DATE					null,
	old_ChangeBy				 VARCHAR2(20) 			null,
	new_ChangeBy				 VARCHAR2(20) 			null,
	Transaction_ID               NUMBER(27,0)			null,
    TransactionType              CHAR(1)       			null,
    TransactionUser              VARCHAR2(20)   		null,
    TransactionDate              DATE       			null	
)';
END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Invoice';
  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
	  '
	  CREATE OR REPLACE TRIGGER AUDIT_LH_LEGALHOLDMATTER
  BEFORE INSERT OR DELETE OR UPDATE ON LH_LEGALHOLDMATTER
  FOR EACH ROW
DECLARE
  v_UserSID            NUMBER(10,0);
  v_AuditUserSID       NUMBER(10,0);
  v_LoginDate          DATE;
  v_LoginName          VARCHAR2(20);
  v_TransactionDate    DATE;

  CURSOR c_AuditUserSID IS
    SELECT UserSID, LoginDate
      FROM AuditUserSID;

BEGIN
  SELECT SYSDATE
    INTO v_TransactionDate
    FROM DUAL;

  SELECT DISTINCT(SID)
    INTO v_UserSID
    FROM V$MYSTAT;

  OPEN c_AuditUserSID;
  LOOP
    FETCH c_AuditUserSID
      INTO v_AuditUserSID, v_LoginDate;
    EXIT WHEN c_AuditUserSID%NOTFOUND;

    IF v_UserSID = v_AuditUserSID and v_LoginDate > (SYSDATE-5/24/60) THEN
      SELECT LoginName
        INTO v_LoginName
        FROM AuditUserSID
        WHERE UserSID = v_UserSID;
      ELSE
        NULL;
    END IF;
  END LOOP;
  CLOSE c_AuditUserSID;

  IF v_LoginName IS NULL THEN
     v_LoginName := ''Unknown'';
    ELSE
      NULL;
  END IF;
  IF INSERTING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''I'', v_LoginName, v_TransactionDate, ''LH_LEGALHOLDMATTER'');	  
	INSERT INTO LH_LEGALHOLDMATTER_AUDIT
      (
       new_ChangeBy,
       new_CreatedBy,
       new_CreatedDate,
       new_LastChange,
       new_LHHoldKey,
       new_LH_LegalHoldMatter_ID,
       new_MatterNumber_ID,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :new.ChangeBy,
       :new.CreatedBy,
       :new.CreatedDate,
       :new.LastChange,
       :new.LHHoldKey,
       :new.LH_LegalHoldMatter_ID,
	   :new.MatterNumber_ID,
       SEQ_AUDITTRANSACTION.CurrVal, ''I'', v_LoginName, v_TransactionDate);
	 ELSIF UPDATING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''U'', v_LoginName, v_TransactionDate, ''LH_LEGALHOLDMATTER'');
    INSERT INTO LH_LEGALHOLDMATTER_AUDIT
      (
       old_ChangeBy,
       old_CreatedBy,
       old_CreatedDate,
       old_LastChange,
       old_LHHoldKey,
       old_LH_LegalHoldMatter_ID,
       old_MatterNumber_ID,
	   new_ChangeBy,
       new_CreatedBy,
       new_CreatedDate,
       new_LastChange,
       new_LHHoldKey,
       new_LH_LegalHoldMatter_ID,
       new_MatterNumber_ID,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :old.ChangeBy,
       :old.CreatedBy,
       :old.CreatedDate,
       :old.LastChange,
       :old.LHHoldKey,
       :old.LH_LegalHoldMatter_ID,
       :old.MatterNumber_ID,
	   :new.ChangeBy,
       :new.CreatedBy,
       :new.CreatedDate,
       :new.LastChange,
       :new.LHHoldKey,
       :new.LH_LegalHoldMatter_ID,
       :new.MatterNumber_ID,
       SEQ_AUDITTRANSACTION.CurrVal, ''U'', v_LoginName, v_TransactionDate);
  ELSIF DELETING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''D'', v_LoginName, v_TransactionDate, ''LH_LEGALHOLDMATTER'');
    INSERT INTO LH_LEGALHOLDMATTER_AUDIT
      (
	   old_ChangeBy,
       old_CreatedBy,
       old_CreatedDate,
       old_LastChange,
       old_LHHoldKey,
       old_LH_LegalHoldMatter_ID,
       old_MatterNumber_ID,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :old.ChangeBy,
       :old.CreatedBy,
       :old.CreatedDate,
       :old.LastChange,
       :old.LHHoldKey,
       :old.LH_LegalHoldMatter_ID,
       :old.MatterNumber_ID,
       SEQ_AUDITTRANSACTION.CurrVal, ''D'', v_LoginName, v_TransactionDate);
  ELSE
    NULL;
  END IF;
END;';
	  END;
  ELSE
    NULL;
  END IF;
END;
/
-- Begin drop tmp_AuditingUpgrade table
DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Invoice';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE 'grant select on LH_LegalHoldMatter_Audit to <LOGIN>';
    END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_ObjectCount         NUMBER(1);
BEGIN
  SELECT COUNT(*)
    INTO v_ObjectCount
    FROM User_Tables
    WHERE Table_Name = 'LH_MATTERSTAFFASSIGNEE';

  IF v_ObjectCount = 1 THEN
	 EXECUTE IMMEDIATE 'DROP TABLE LH_MATTERSTAFFASSIGNEE';
	 COMMIT;
    ELSE
      NULL;
  END IF;
END;
/

create table LH_MatterStaffAssignee  (
   LH_MatterStaffAssignee_ID NUMBER(10,0)                    not null,
   MatterPlayer_ID    		 NUMBER(10,0),
   LH_MatterStaff_ID 		 VARCHAR2(50),
   LH_Hold_ID         		 VARCHAR2(50),
   CreatedDate       		 DATE,
   LastChange         		 DATE,
   ChangeBy           		 VARCHAR2(50),
   constraint PK_LH_MATTERSTAFFASSIGNEE primary key (LH_MatterStaffAssignee_ID)
   using index tablespace <INDEX_TABLESPACE>
);

create index IDX_LHM_MATTERPLAYER_ID on LH_MatterStaffAssignee (
MatterPlayer_ID asc
)
tablespace <INDEX_TABLESPACE>;

alter table LH_MatterStaffAssignee
   add constraint FK_LH_MATTE_REF_3144_MATTERPL foreign key (MatterPlayer_ID)
      references MatterPlayer (MatterPlayer_ID);

/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Invoice';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
'
create table LH_MatterStaffAssignee_Audit  (
   old_LH_MatterStaffAssignee_ID NUMBER(10,0)          null,
   new_LH_MatterStaffAssignee_ID NUMBER(10,0)          null,
   old_MatterPlayer_ID    		 NUMBER(10,0)		   null,
   new_MatterPlayer_ID    		 NUMBER(10,0)		   null,
   old_LH_MatterStaff_ID 		 VARCHAR2(50)		   null,
   new_LH_MatterStaff_ID 		 VARCHAR2(50)		   null,
   old_LH_Hold_ID         		 VARCHAR2(50)		   null,
   new_LH_Hold_ID         		 VARCHAR2(50)		   null,
   old_CreatedDate       		 DATE		           null,
   new_CreatedDate       		 DATE		           null,
   old_LastChange         		 DATE				   null,
   new_LastChange         		 DATE				   null,   
   old_ChangeBy           		 VARCHAR2(50)		   null,
   new_ChangeBy           		 VARCHAR2(50)		   null,
   Transaction_ID                NUMBER(27,0)		   null,
   TransactionType               CHAR(1)       		   null,
   TransactionUser               VARCHAR2(20)   	   null,
   TransactionDate               DATE       		   null	
)
';
END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Invoice';
  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE
	  '
	  CREATE OR REPLACE TRIGGER AUDIT_LH_MATTERSTAFFASSIGNEE
  BEFORE INSERT OR DELETE OR UPDATE ON LH_MATTERSTAFFASSIGNEE
  FOR EACH ROW
DECLARE
  v_UserSID            NUMBER(10,0);
  v_AuditUserSID       NUMBER(10,0);
  v_LoginDate          DATE;
  v_LoginName          VARCHAR2(20);
  v_TransactionDate    DATE;

  CURSOR c_AuditUserSID IS
    SELECT UserSID, LoginDate
      FROM AuditUserSID;
	  
  BEGIN
  SELECT SYSDATE
    INTO v_TransactionDate
    FROM DUAL;

  SELECT DISTINCT(SID)
    INTO v_UserSID
    FROM V$MYSTAT;

  OPEN c_AuditUserSID;
  LOOP
    FETCH c_AuditUserSID
      INTO v_AuditUserSID, v_LoginDate;
    EXIT WHEN c_AuditUserSID%NOTFOUND;

    IF v_UserSID = v_AuditUserSID and v_LoginDate > (SYSDATE-5/24/60) THEN
      SELECT LoginName
        INTO v_LoginName
        FROM AuditUserSID
        WHERE UserSID = v_UserSID;
      ELSE
        NULL;
    END IF;
  END LOOP;
  CLOSE c_AuditUserSID;

  IF v_LoginName IS NULL THEN
     v_LoginName := ''Unknown'';
    ELSE
      NULL;
  END IF;
  IF INSERTING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''I'', v_LoginName, v_TransactionDate, ''LH_MATTERSTAFFASSIGNEE'');
    INSERT INTO LH_MATTERSTAFFASSIGNEE_AUDIT
      (
       new_ChangeBy,
       new_CreatedDate,
	   new_LH_Hold_ID,
	   new_LH_MatterStaffAssignee_ID,             
	   new_LH_MatterStaff_ID,
	   new_MatterPlayer_ID,
	   new_LastChange,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
      :new.ChangeBy,
      :new.CreatedDate,
	  :new.LH_Hold_ID,
	  :new.LH_MatterStaffAssignee_ID,             
	  :new.LH_MatterStaff_ID,
	  :new.MatterPlayer_ID,
	  :new.LastChange,
       SEQ_AUDITTRANSACTION.CurrVal, ''I'', v_LoginName, v_TransactionDate);
	ELSIF UPDATING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''U'', v_LoginName, v_TransactionDate, ''LH_MATTERSTAFFASSIGNEE'');
    INSERT INTO LH_MATTERSTAFFASSIGNEE_AUDIT
      (
       old_ChangeBy,
       old_CreatedDate,
	   old_LH_Hold_ID,
	   old_LH_MatterStaffAssignee_ID,             
	   old_LH_MatterStaff_ID,
	   old_MatterPlayer_ID,
	   old_LastChange,
       new_ChangeBy,
       new_CreatedDate,
	   new_LH_Hold_ID,
	   new_LH_MatterStaffAssignee_ID,             
	   new_LH_MatterStaff_ID,
	   new_MatterPlayer_ID,
	   new_LastChange,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :old.ChangeBy,
       :old.CreatedDate,
	   :old.LH_Hold_ID,
	   :old.LH_MatterStaffAssignee_ID,             
	   :old.LH_MatterStaff_ID,
	   :old.MatterPlayer_ID,
	   :old.LastChange,
       :new.ChangeBy,
       :new.CreatedDate,
	   :new.LH_Hold_ID,
	   :new.LH_MatterStaffAssignee_ID,             
	   :new.LH_MatterStaff_ID,
	   :new.MatterPlayer_ID,
	   :new.LastChange,
       SEQ_AUDITTRANSACTION.CurrVal, ''U'', v_LoginName, v_TransactionDate);
	 ELSIF DELETING THEN
    INSERT INTO AuditTransaction
      (AuditTransaction_ID, TransactionType, TransactionUser, TransactionDate, TableName)
    VALUES
      (SEQ_AUDITTRANSACTION.NextVal, ''D'', v_LoginName, v_TransactionDate, ''LH_MATTERSTAFFASSIGNEE'');
    INSERT INTO LH_MATTERSTAFFASSIGNEE_AUDIT
      (
       old_ChangeBy,
       old_CreatedDate,
	   old_LH_Hold_ID,
	   old_LH_MatterStaffAssignee_ID,             
	   old_LH_MatterStaff_ID,
	   old_MatterPlayer_ID,
	   old_LastChange,
       Transaction_ID, TransactionType, TransactionUser, TransactionDate)
    VALUES
      (
       :old.ChangeBy,
       :old.CreatedDate,
	   :old.LH_Hold_ID,
	   :old.LH_MatterStaffAssignee_ID,             
	   :old.LH_MatterStaff_ID,
	   :old.MatterPlayer_ID,
	   :old.LastChange,
       SEQ_AUDITTRANSACTION.CurrVal, ''D'', v_LoginName, v_TransactionDate);
  ELSE
    NULL;
  END IF;
END;';
END;
  ELSE
    NULL;
  END IF;
END;
/

DECLARE
  v_UpgradeObject       CHAR(1);
BEGIN
  SELECT UpgradeTable
    INTO v_UpgradeObject
    FROM tmp_AuditingUpgrade
    WHERE TableName = 'Invoice';

  IF v_UpgradeObject = 'T' THEN
    BEGIN
      EXECUTE IMMEDIATE 'grant select on LH_MatterStaffAssignee_Audit to <LOGIN>';
    END;
  ELSE
    NULL;
  END IF;
END;
/

drop table tmp_AuditingUpgrade;

-- End drop tmp_AuditingUpgrade table

------------------End new table auth--------------------------------

-----------------BEGIN Trigger section------------------------------

--UPD-8843

DECLARE
v_exist NUMBER(10,0):=0;
BEGIN
  SELECT Count(*) into v_exist FROM user_triggers where TRIGGER_NAME='TR_DFVALUES_ON_VPC';
  IF v_exist > 0 THEN
   EXECUTE IMMEDIATE 'drop trigger TR_DFVALUES_ON_VPC';
  END IF;
END;
/

create or replace TRIGGER TR_DFVALUES_ON_VPC AFTER INSERT ON viewProfile FOR EACH ROW
DECLARE
	V_VIEWPROFILECOLUMNID NUMBER(10,0);
BEGIN
  --INSERTED
  IF INSERTING THEN
    --101) User account associated to a person.
    SELECT Next_ID INTO V_VIEWPROFILECOLUMNID from CurrentID where TableName = 'ViewProfileColumn';
    
    INSERT INTO VIEWPROFILECOLUMN
    (
      VIEWPROFILECOLUMN_ID,
      VIEWPROFILE_ID,
      TAB_ID,
      COLUMNNAME,
      HIDDEN,
      READONLY
    )
   SELECT
		V_VIEWPROFILECOLUMNID+1,:NEW.ViewProfile_ID, 5106,'cancelDate','T','F' FROM DUAL UNION ALL
   SELECT
    V_VIEWPROFILECOLUMNID+2,:NEW.ViewProfile_ID ,5106,'acquired_eid','T','F' FROM DUAL;
    
   update CurrentID set Next_ID = V_VIEWPROFILECOLUMNID+2 where TableName = 'ViewProfileColumn';
  END IF;
 END;
/                

-----------------END Trigger section------------------------------

---------------- Begin Data Changes Section ----------------

--initialization
insert into CurrentID values ('LH_LegalHoldMatter', 10000);
insert into CurrentID values ('LH_MatterStaffAssignee', 10000);
commit;
/
--Adding new category for legalhold
DECLARE
lookupCodeCatID NUMBER(10,0); LookupCodeID NUMBER(10,0); v_exist number(10,0);
BEGIN
  SELECT COUNT(*) INTO v_exist FROM LookupCodeCategory WHERE CategoryName = 'People Status';
  IF v_exist < 1 THEN
		SELECT MAX(LookupCodeCategory_ID) into  lookupCodeCatID FROM LookupCodeCategory WHERE LookupCodeCategory_ID < 10000;
      IF lookupCodeCatID < 9999 THEN
        INSERT INTO LookupCodeCategory VALUES (lookupCodeCatID + 1, 'People Status', NULL, 'T', 'SYSTEM', NULL);
        SELECT MAX(LookupCode_ID) into LookupCodeID  FROM LookupCode WHERE LookupCode_ID < 10000;
        IF LookupCodeID < 9999 THEN
          INSERT INTO LookupCode VALUES (LookupCodeID + 1, lookupCodeCatID + 1, 'Active', 'F', 'F', 'SYSTEM', NULL);
          INSERT INTO LookupCode VALUES (LookupCodeID + 2, lookupCodeCatID + 1, 'Inactive', 'F', 'F', 'SYSTEM', NULL);
          COMMIT;
        ELSE
          SELECT Next_ID INTO LookupCodeID FROM CurrentID WHERE TableName = 'LookupCode';
          INSERT INTO LookupCode VALUES (LookupCodeID + 1, lookupCodeCatID + 1, 'Active', 'F', 'F', 'SYSTEM', NULL);
          INSERT INTO LookupCode VALUES (LookupCodeID + 2, lookupCodeCatID + 1, 'Inactive', 'F', 'F', 'SYSTEM', NULL);
          UPDATE CurrentID SET Next_ID = LookupCodeID + 2 WHERE TableName = 'LookupCode';	
		  COMMIT;
        END IF;
      ELSE
        SELECT Next_ID INTO lookupCodeCatID FROM CurrentID WHERE TableName = 'LookupCodeCategory';
        INSERT INTO LookupCodeCategory VALUES (lookupCodeCatID + 1, 'People Status', NULL, 'T', 'SYSTEM', NULL);
        UPDATE CurrentID SET Next_ID = lookupCodeCatID + 1 WHERE TableName = 'LookupCodeCategory';		
        SELECT MAX(LookupCode_ID) INTO LookupCodeID FROM LookupCode WHERE LookupCode_ID < 10000;
        IF LookupCodeID < 9999 THEN      
          INSERT INTO LookupCode VALUES (LookupCodeID + 1, lookupCodeCatID + 1, 'Active', 'F', 'F', 'SYSTEM', NULL);
          INSERT INTO LookupCode VALUES (LookupCodeID + 2, lookupCodeCatID + 1, 'Inactive', 'F', 'F', 'SYSTEM', NULL);
          COMMIT;
        ELSE
          SELECT Next_ID INTO LookupCodeID FROM CurrentID WHERE TableName = 'LookupCode';
          INSERT INTO LookupCode VALUES (LookupCodeID + 1, lookupCodeCatID + 1, 'Active', 'F', 'F', 'SYSTEM', NULL);
          INSERT INTO LookupCode VALUES (LookupCodeID + 2, lookupCodeCatID + 1, 'Inactive', 'F', 'F', 'SYSTEM', NULL);
          UPDATE CurrentID SET Next_ID = LookupCodeID + 2 WHERE TableName = 'LookupCode';
          COMMIT;
        END IF;
      END IF;
   END IF;
END;
/

---------------- End Data Changes Section ----------------

-- Begin grant permissions

-- Tables


grant select, insert, update, delete on LH_LegalHoldMatter to <LOGIN>;
/
grant select, insert, update, delete on LH_MatterStaffAssignee to <LOGIN>;
/
grant select, insert, update, delete on Company to <LOGIN>;
/
grant select, insert, update, delete on Matter to <LOGIN>;
/
grant select, insert, update, delete on Person to <LOGIN>;
/

--procedures
grant execute on MLHGetPlayerInfo to <LOGIN>;
/
--Views
grant select on VLH_MatterTypes_Status to <LOGIN>;
/
grant select on VLH_RolesCodes_Status to <LOGIN>;
/
-- End grant permissions

-- Update DatabaseHistory

insert into DatabaseHistory values
(
  '8.11.0.27.00',
  '11-FEB-2018',
  'Suite81101800-81102700-ORA.sql',
  'Upgrades the database from 8.11.0.18.00 to 8.11.0.27.00.',
  SYSDATE
);
/
commit;